function P=PermtrLength(x,y,CoordType,Circle,Smoothing);
%Fuction to calculate perimeter length of the area or curve length.
%Inputs:
%x	- x coordinate
%y	- y coordinate
%CoordType	- orthogonal (1)* or polar (Th,R) (2) coordinate system (x,y), >=2 points
%Circle	- if the last point should be connected to the first one (1) or not (0)*
%Smoothing	- number of additional interpolation points to make curve smooth. Default - 0 (no smoothing)

%Output:
%P	- perimeter length
if nargin < 5
	CoordType=1;	%Orthogonal
	Circle=0;	%Not Circle
	Smoothing=0;
end

if length(x)<=1	%Only one point in the line
	P=0;
else	%more than one point in the line
	
	if CoordType==2	%Polar
		[x,y]=pol2cart(x,y);
	end
	
	if Circle==1	%Circle
		x(end+1)=x(1);
		y(end+1)=y(1);
	end
	
	Smoothing=round(Smoothing);
	if Smoothing>0	%Smoothing curve
		yy = [x; y];	xx = 1:length(x);
		pp = spline(xx,yy);
		yy = ppval(pp, linspace(1,length(x),length(x)*Smoothing));
		x=yy(1,:);	y=yy(2,:);
	end	
	
	P=sum(((x(2:end)-x(1:end-1)).^2+(y(2:end)-y(1:end-1)).^2).^0.5);
end 	%Only one point in the line