function POINT=VRML_remove_duplicate_vertices(POINT,minimal_distance,distance_type,discriminate_normals, average_normals,...
	discriminate_color, average_color)
%Function to remove all the duplicate vertices identical in coordinames and (if selected) normals and colors
%Inputs:
%POINT	- structural array with VRML data
%minimal_distance	- Minimal distance between two vertices' coordinates to consider them identical
%distance_type	- type of minimal distance value <'Absolute'> (in Angstroms) or 'Relative' (as a portion of  minimal edge length)
%discriminate_normals	- flag to disrciminate <1> or not <0>* normals considering vertices to be identical.
%average_normals	- If checked, mean normal will be calculated for identical vertices
%discriminate_color	- flag to disrciminate <1> or not <0>* colors considering vertices to be identical. 
%average_color	- If checked, mean color will be calculated for identical vertices
%Outputs:
%POINT	- structural array with VRML data

%global POINT
tic; ProgressReportTime=toc;
if nargin==1	%Only input matrix is submitted
	discriminate_normals=0;
	average_normals=0;
	discriminate_color=0;
	average_color=0;
end

disp('Duplicate vertices removal');
disp(['Initial structure: ', num2str(length(POINT.Coordinate3)), ' vertices of ',...
		num2str(length(POINT.Material)), ' colors, ',...
		num2str(length(POINT.Normal)), ' normals, and ',...
		num2str(length(POINT.IndexedFaceSet)), ' facets.']);


%___________ initializations
InitialNumberOfVertices=size(POINT.Coordinate3,2);
vertices_remove=zeros(1,InitialNumberOfVertices);	%Initialize and array of flags to remove vertex as a duplicate
vertices_indexes=zeros(1,InitialNumberOfVertices);	%Initialize and array of old and new indexes for all the old vertices
vertices_indexes(1)=1;	%The first vertex remain anyway
last_vertex_number=1;	%Number of the last vertex in the lew cleaned index

if minimal_distance==0	%Exact coincedence of coordinates
% 	
% 	%_______________ cycle for marking vertices to remove, creating new index numbers for remaining vertices, and making cross-references for removed ones
% 	for i=2:InitialNumberOfVertices
% 		for  b=(i-1):-1:1	%looking back through all the passed nodes up to the first identical node met
% 			if POINT.Coordinate3(1,i)~=POINT.Coordinate3(1,b)|...
% 					POINT.Coordinate3(2,i)~=POINT.Coordinate3(2,b)|...
% 					POINT.Coordinate3(3,i)~=POINT.Coordinate3(3,b)	%Vertices are different
% 			elseif discriminate_normals&(...
% 					POINT.Normal(1,i)~=POINT.Normal(1,b)|...
% 					POINT.Normal(2,i)~=POINT.Normal(2,b)|...
% 					POINT.Normal(3,i)~=POINT.Normal(3,b))%Vertices are different
% 			elseif discriminate_color&(...
% 					POINT.Material(1,i)~=POINT.Material(1,b)|...
% 					POINT.Material(2,i)~=POINT.Material(2,b)|...
% 					POINT.Material(3,i)~=POINT.Material(3,b))	%Vertices are different
% 			else 		%Vertices are IDENTICAL by the criteria selected
% 				vertices_remove(i)=1;	%Mark the last (i) vertex to remove
% 				vertices_indexes(i)=vertices_indexes(b);
% 				break;
% 			end
% 			
% 		end
% 		if vertices_remove(i)==0	%Vertex to leave
% 			last_vertex_number=last_vertex_number+1;	%One more vertex to leave
% 			vertices_indexes(i)=last_vertex_number;
% 		end
% 		%Progress report block - optional
% 		CurrentProgressTime=toc;
% 		if (CurrentProgressTime-ProgressReportTime)>0.5	%Time to report progress
% 			try ProgressBarLocal(i,InitialNumberOfVertices);%Set current value on the local progress bar
% 			end
% 			ProgressReportTime=CurrentProgressTime;
% 		end	%Time to report progress
% 		
% 		
% 	end
% 	
	
	%_______________ cycle for marking vertices to remove, creating new index numbers for remaining vertices, and making cross-references for removed ones
	b=1:InitialNumberOfVertices;
	last_vertex_number=0;
	while ~isempty(b)	%There are some unchecked vertices
		
		i=b(1);	%the first of the unchecked vertices - vertex to leave
		last_vertex_number=last_vertex_number+1;	%One more vertex to leave
		vertices_indexes(i)=last_vertex_number;
		
		b=b(2:end);	%remaining unchecked vertices
		
		if ~isempty(b)	%there are some remaining unchecked vertices in current ceck
			coinciding_vertices=find(...
				POINT.Coordinate3(1,b)==POINT.Coordinate3(1,i)&...
				POINT.Coordinate3(2,b)==POINT.Coordinate3(2,i)&...
				POINT.Coordinate3(3,b)==POINT.Coordinate3(3,i));	%Find vertices close enough incoordinates
			
			if ~isempty(coinciding_vertices)&discriminate_normals	%There were some vertices found and normals are to be discriminated
				b=b(coinciding_vertices);	%Convert indices to their real values
				coinciding_vertices=find(...
					POINT.Normal(1,b)==POINT.Normal(1,i)&...
					POINT.Normal(2,b)==POINT.Normal(2,i)&...
					POINT.Normal(3,b)==POINT.Normal(3,i));	%Find vertices close enough incoordinates
			end	%There were some vertices found and normals are to be discriminated
			
			if ~isempty(coinciding_vertices)&discriminate_color	%There were some vertices found and normals are to be discriminated
				b=b(coinciding_vertices);	%Convert indices to their real values
				coinciding_vertices=find(...
					POINT.Material(1,b)==POINT.Material(1,i)&...
					POINT.Material(2,b)==POINT.Material(2,i)&...
					POINT.Material(3,b)==POINT.Material(3,i));	%Find vertices close enough incoordinates
			end	%There were some vertices found and normals are to be discriminated
			
			if ~isempty(coinciding_vertices)	%There were some vertices found
				b=b(coinciding_vertices);	%Convert indices to their real values
				vertices_remove(b)=1;	%Mark the last (i) vertex to remove
				vertices_indexes(b)=vertices_indexes(i);
			end	%There were some vertices found and normals are to be discriminated
			
			b=find(vertices_indexes==0);	%find all unchecked vertices
			
		end%there are some remaining unchecked vertices in current ceck
		
		%Progress report block - optional
		CurrentProgressTime=toc;
		if (CurrentProgressTime-ProgressReportTime)>0.5	%Time to report progress
			try ProgressBarLocal(i,InitialNumberOfVertices);%Set current value on the local progress bar
			end
			ProgressReportTime=CurrentProgressTime;
		end	%Time to report progress
	end	%There are some unchecked vertices
else 	%Approximate coincedence of coordinates
	switch distance_type	%type of minimal distance value <'Absolute'> (in Angstroms) or 'Relative' (as a portion of  minimal edge length)
	case 'Absolute'	%(in Angstroms)
	case 'Relative' %(as a portion of  minimal edge length)
		%Calculate minimal edge length
		DeltaX=[(POINT.Coordinate3(1,POINT.IndexedFaceSet(2,:))-POINT.Coordinate3(1,POINT.IndexedFaceSet(1,:))), ...
				(POINT.Coordinate3(1,POINT.IndexedFaceSet(3,:))-POINT.Coordinate3(1,POINT.IndexedFaceSet(2,:))), ...
				(POINT.Coordinate3(1,POINT.IndexedFaceSet(1,:))-POINT.Coordinate3(1,POINT.IndexedFaceSet(3,:)))];	%DeltaX for all the facets
		DeltaY=[(POINT.Coordinate3(2,POINT.IndexedFaceSet(2,:))-POINT.Coordinate3(2,POINT.IndexedFaceSet(1,:))), ...
				(POINT.Coordinate3(2,POINT.IndexedFaceSet(3,:))-POINT.Coordinate3(2,POINT.IndexedFaceSet(2,:))), ...
				(POINT.Coordinate3(2,POINT.IndexedFaceSet(1,:))-POINT.Coordinate3(2,POINT.IndexedFaceSet(3,:)))];	%DeltaY for all the facets
		DeltaZ=[(POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))-POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))), ...
				(POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:))-POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))), ...
				(POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))-POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:)))];	%DeltaZ for all the facets
		MinEdge=(DeltaX.^2+DeltaY.^2+DeltaZ.^2);
		MinEdge=min(MinEdge(:))^0.5;%!!!;	%Minimal Edge length
		minimal_distance=MinEdge*minimal_distance;	%Minimal distance, calculated as a portion of the minimal edge length
	end	%type of minimal distance value
	
	%_______________ cycle for marking vertices to remove, creating new index numbers for remaining vertices, and making cross-references for removed ones
	b=1:InitialNumberOfVertices;
	last_vertex_number=0;
	while ~isempty(b)	%There are some unchecked vertices
		
		i=b(1);	%the first of the unchecked vertices - vertex to leave
		last_vertex_number=last_vertex_number+1;	%One more vertex to leave
		vertices_indexes(i)=last_vertex_number;
		
		b=b(2:end);	%remaining unchecked vertices
		
		if ~isempty(b)	%there are some remaining unchecked vertices in current ceck
			coinciding_vertices=find(...
				abs(POINT.Coordinate3(1,b)-POINT.Coordinate3(1,i))<minimal_distance&...
				abs(POINT.Coordinate3(2,b)-POINT.Coordinate3(2,i))<minimal_distance&...
				abs(POINT.Coordinate3(3,b)-POINT.Coordinate3(3,i))<minimal_distance);	%Find vertices close enough incoordinates
			
			if ~isempty(coinciding_vertices)&discriminate_normals	%There were some vertices found and normals are to be discriminated
				b=b(coinciding_vertices);	%Convert indices to their real values
				coinciding_vertices=find(...
					POINT.Normal(1,b)==POINT.Normal(1,i)&...
					POINT.Normal(2,b)==POINT.Normal(2,i)&...
					POINT.Normal(3,b)==POINT.Normal(3,i));	%Find vertices close enough incoordinates
			end	%There were some vertices found and normals are to be discriminated
			
			if ~isempty(coinciding_vertices)&discriminate_color	%There were some vertices found and normals are to be discriminated
				b=b(coinciding_vertices);	%Convert indices to their real values
				coinciding_vertices=find(...
					POINT.Material(1,b)==POINT.Material(1,i)&...
					POINT.Material(2,b)==POINT.Material(2,i)&...
					POINT.Material(3,b)==POINT.Material(3,i));	%Find vertices close enough incoordinates
			end	%There were some vertices found and normals are to be discriminated
			
			if ~isempty(coinciding_vertices)	%There were some vertices found
				b=b(coinciding_vertices);	%Convert indices to their real values
				vertices_remove(b)=1;	%Mark the last (i) vertex to remove
				vertices_indexes(b)=vertices_indexes(i);
			end	%There were some vertices found and normals are to be discriminated
			
			b=find(vertices_indexes==0);	%find all unchecked vertices
			
		end%there are some remaining unchecked vertices in current ceck
		
		%Progress report block - optional
		CurrentProgressTime=toc;
		if (CurrentProgressTime-ProgressReportTime)>0.5	%Time to report progress
			try ProgressBarLocal(i,InitialNumberOfVertices);%Set current value on the local progress bar
			end
			ProgressReportTime=CurrentProgressTime;
		end	%Time to report progress
	end	%There are some unchecked vertices
end	%Exact coincedence of coordinates


%________________________  creating new cleared vertices list
POINT.Coordinate3=POINT.Coordinate3(:,find(1-vertices_remove));

%________________________ Normals averaging and removal
if length(POINT.Normal)>0
	if average_normals > 0
		for i=1:InitialNumberOfVertices
			if length(find(vertices_indexes==i))>1
				POINT.Normal(1,find(vertices_indexes==i))=mean(POINT.Normal(1,find(vertices_indexes==i)));
				POINT.Normal(2,find(vertices_indexes==i))=mean(POINT.Normal(2,find(vertices_indexes==i)));
				POINT.Normal(3,find(vertices_indexes==i))=mean(POINT.Normal(3,find(vertices_indexes==i)));
			end
		end
	end
	POINT.Normal=POINT.Normal(:,find(1-vertices_remove));	%Remove marked vertices
end


%________________________ Colors averaging and removal
if length(POINT.Material)>0
	if average_color > 0
		for i=1:InitialNumberOfVertices
			if length(find(vertices_indexes==i))>1
				POINT.Material(1,find(vertices_indexes==i))=mean(POINT.Material(1,find(vertices_indexes==i)));
				POINT.Material(2,find(vertices_indexes==i))=mean(POINT.Material(2,find(vertices_indexes==i)));
				POINT.Material(3,find(vertices_indexes==i))=mean(POINT.Material(3,find(vertices_indexes==i)));
			end
		end
	end
	POINT.Material=POINT.Material(:,find(1-vertices_remove));	%Remove marked vertices
end

%_________________________ remapping references in facets to new vertices list
for i=1:InitialNumberOfVertices
	IndexedFaceSet=POINT.IndexedFaceSet(1:3,:);
	IndexedFaceSet(find(IndexedFaceSet==i))=vertices_indexes(i);
	POINT.IndexedFaceSet(1:3,:)=IndexedFaceSet;
end

disp(['Final structure:   ', num2str(length(POINT.Coordinate3)), ' vertices of ',...
		num2str(length(POINT.Material)), ' colors, ',...
		num2str(length(POINT.Normal)), ' normals, and ',...
		num2str(length(POINT.IndexedFaceSet)), ' facets. Time spent, s: ',...
		num2str(toc)]);
