function [RBinsZ,ResProf]=condprof(s,PlotProf,PlotLand,PrintProf,PrintLand,ImageProf,ImageLand,SaveProf,SaveLand,CondParm,CondParmType,ProfType,HydrShell)
%hydpran is the program for creating and analysis of conductance profiles
%Inputs:	
%PlotProf		Plot Property profiles
%PlotLand		Plot Property landscape
%PrintProf		Print Property profiles
%PrintLand		Print Property landscape
%ImageProf		Image Property profiles
%ImageLand		Image Property landscape
%SaveProf		Save Property profiles
%SaveLand		Save Property landscape
%CondParm		Value of conductivity
%CondParmType		Type of conductivity parameter
%ProfType		Geometrical profile type - radius or area
%s		Get file list

if ~isempty(s)
	RadProf=[];
	MBinsZ=[];
	ProfNames={};
	for m=1:length(s)
		
		%=================Read hydration energy profile file into array
		fh=fopen(s{m},'r');
		ProgressBarFile(m);
		%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
		%t=sscanf(fgets(fh),'%s\t');
		ft=fopen('temptemp.txt','w');	%temporal file
		fprintf(ft,'%c',fgets(fh));	%saves the first line with field names from HE profile file
		fclose(ft);
		tProfNames = textread('temptemp.txt','%s','delimiter','\t');
		for pr=2:length(tProfNames)
			tProfNames{pr}=[s{m},'_',tProfNames{pr}];	%add file name before the profile name
		end
		if length(ProfNames)==0
			ProfNames={tProfNames{2:end}};
		else
			ProfNames=[ProfNames,{tProfNames{2:end}}];
		end
		delete 'temptemp.txt';
		fclose(fh);
		
		tRadProf=textread(s{m},'%f','delimiter','\n','headerlines',1);
		tRadProf=reshape(tRadProf(1:floor(length(tRadProf)/length(tProfNames))*length(tProfNames)),...
			length(tProfNames),floor(length(tRadProf)/length(tProfNames)))';
		MBinsZ=tRadProf(:,1);	%column with position values
		RadProf=[RadProf,tRadProf(:,2:end)];	%columns with hydrophobicity profiles
		disp([num2str(m),'. ',s{m},':      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(tRadProf,2)-1) ,'-profile(s) file read']);
		SndNp(2);
	end
	RadProf=RadProf';
	
	disp(['Total:      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(RadProf,1)) ,'-profile(s) matrix created']);
	
	%========= recalculate area to radius - for uniformity
	switch ProfType	%Geometrical profile type - radius or area
	case 1	%Radius
	case 2	%Area
		RadProf=(RadProf/pi).^0.5;	%Now it is radii matrix
	end	%Geometrical profile type - radius or area
	
	%========== substract unpermeable Hydration shell
	RadProf=RadProf-HydrShell;
	
	%========== Plotting 2-D hydration energy landscape
	if PlotProf|PrintProf|ImageProf
		%==========plotting hydration energy profile
		
		for tt=1:size(RadProf,1)
			figure
			plot(MBinsZ,RadProf(tt,:));
			if PrintProf==1	%Print profile
				print;
			end
			if ImageProf==1	%Print profile
				tstr=['print -dpng ''Initial_radius_profile_of_the_',ProfNames{tt},'.png'''];
				eval(tstr);
			end
			if PlotProf==0	%Don't plot profile
				close;
			end
		end
		figure
		plot(MBinsZ,RadProf');

        if PrintProf==1	%Print profile
            print;
        end
        if ImageProf==1	%Print profile
            tstr=['print -dpng ''Initial_radius_profile_of_the_',s{m},'.png'''];
            eval(tstr);
        end
        if PlotProf==0	%Don't plot profile
            close;
        end
    end
    
	if (PlotLand|PrintLand|ImageLand)&(size(RadProf,1) > 2)
		figure
		hp=surfl(MBinsZ,[1:size(RadProf,1)],RadProf);
		colormap('bone');
		shading interp
		set(hp,'EdgeColor','k')
		%light('Position',[ -50 -250 3000 ])
		set(hp,'MeshStyle','row');
		xlabel('Position, A');
		ylabel('File #');
		zlabel('Radius, Angstrom');
		set(gca,'YTick',1:size(RadProf,1));
		set(gca,'YTickLabel',ProfNames);
		if PrintLand==1	%Print landscape
			print;
		end
		if ImageLand==1	%Print landscape
			tstr=['print -dpng ''Initial_radius_landscape_-_all_the_files.png'''];
			eval(tstr);
		end
		if PlotLand==0	%Don't plot landscape
			close;
		end

	end
	
	%Initialize resistancce profile matrix
	ResProf=zeros(size(RadProf,1),(size(RadProf,2)+1));
	z=1:(size(RadProf,2)-1);	%Indices along the Z axis
	
	%Define new bins medianes for resistance profile
	RBinsZ(z+1)=(MBinsZ(z)+MBinsZ(z+1))/2;	%Mew bins medians
	RBinsZ(1)=RBinsZ(2)-(MBinsZ(2)-MBinsZ(1));	%Add first new bin - describes access resistance at the entrance (lowest z)
	RBinsZ(end+1)=RBinsZ(end)+(MBinsZ(end)-MBinsZ(end-1));	%Add last new bin - describes access resistance at the exit (highest z)
	
	%Calculate the access resistances
	ResProf(:,1)=100./(CondParm*4*RadProf(:,1));	%entrance resistance, in GOhn
	ResProf(:,end)=100./(CondParm*4*RadProf(:,end));	%exit resistance, in GOhn
	
	%Calculate the channel slices resistances for each file line
	for m=1:length(ProfNames)
		ResProf(m,(z+1))=100*diff(MBinsZ)'./(CondParm*pi*((RadProf(m,z)+RadProf(m,z+1))/2).^2);%slice resistance, in GOhn
	end
	
	%Integrate all the resistances
	Resistance=sum(ResProf,2);	%Vector of integral resistances, in GOhms
	Conductance=1./Resistance;	%Vector of integral resistances, in nS
	
	if PlotProf|PrintProf|ImageProf
		%==========plotting hydration energy profile
			for tt=1:size(ResProf,1)
				figure
				plot(RBinsZ,ResProf(tt,:));
				if PrintProf==1	%Print profile
					print;
				end
				if ImageProf==1	%Print profile
					tstr=['print -dpng ''Resistance_profile_of_the_',ProfNames{tt},'.png'''];
					eval(tstr);
				end
				if PlotProf==0	%Don't plot profile
					close;
				end
			end
			figure
			plot(RBinsZ,ResProf');
	end
	
	if PrintProf==1	%Print profile
		print;
	end
	if ImageProf==1	%Print profile
		tstr=['print -dpng ''Resistance_profile_-_all_the_files.png'''];
		eval(tstr);
	end
	if PlotProf==0	%Don't plot profile
		close;
	end
	
	%Save calculation results
	for m=1:length(ProfNames)
		%==========saving separate hydration energy profile
		fh=fopen([ProfNames{m},'_res-sum.txt'],'w');
		fprintf(fh,'%s\t','File','Conductance, nS','Resistance, GOhm','Low Z Access Resistance, GOhm','Internal Channel Resistance, GOhm');
		fprintf(fh,'%s\n', 'High Z Access Resistance, GOhm');
		fprintf(fh,'%s\t', ProfNames{m});
		fprintf(fh,'%16.14g\t', Conductance(m));
		fprintf(fh,'%16.14g\t', Resistance(m));
		fprintf(fh,'%16.14g\t', ResProf(m,1));
		fprintf(fh,'%16.14g\t', sum(ResProf(m,2:(end-1))));
		fprintf(fh,'%16.14g\n', ResProf(m,end));
		fclose(fh);
	end
	
	fh=fopen('all_files_res-sum.txt','w');
	fprintf(fh,'%s\t','File','Conductance, nS','Resistance, GOhm','Low Z Access Resistance, GOhm','Internal Channel Resistance, GOhm');
	fprintf(fh,'%s\n', 'High Z Access Resistance, GOhm');
	for m=1:length(ProfNames)
		%==========saving separate hydration energy profile
		fprintf(fh,'%s\t', ProfNames{m});
		fprintf(fh,'%16.14g\t', Conductance(m));
		fprintf(fh,'%16.14g\t', Resistance(m));
		fprintf(fh,'%16.14g\t', ResProf(m,1));
		fprintf(fh,'%16.14g\t', sum(ResProf(m,2:(end-1))));
		fprintf(fh,'%16.14g\n', ResProf(m,end));
	end
	fclose(fh);

	
	
	if SaveProf
		for m=1:length(ProfNames)
			%==========saving separate hydration energy profile
			fh=fopen([ProfNames{m},'_res.txt'],'w');
			fprintf(fh,'%s\t','Position');
			fprintf(fh,'%s\n', ProfNames{m});
			for i=1:length(RBinsZ)
				fprintf(fh,'%16.14g\t', RBinsZ(i));fprintf(fh,'%16.14g\n', ResProf(m,i));
			end
			fclose(fh);
		end
	end
	
	if (PlotLand|PrintLand|ImageLand)&(size(RadProf,1) > 2)
		figure
		hp=surfl(RBinsZ,[1:size(ResProf,1)],ResProf);
		colormap('bone');
		shading interp
		set(hp,'EdgeColor','k')
		%light('Position',[ -50 -250 3000 ])
		set(hp,'MeshStyle','row');
		xlabel('Position, A');
		ylabel('File #');
		zlabel('Resistance of slice');
		set(gca,'YTick',1:size(ResProf,1));
		set(gca,'YTickLabel',ProfNames);
        if PrintLand==1	%Print landscape
            print;
        end
        if ImageLand==1	%Print landscape
            tstr=['print -dpng ''Resistance_landscape_of_the_',ProfNames{m},'.png'''];
            eval(tstr);
        end
        if PlotLand==0	%Don't plot landscape
            close;
        end
	end
	
	if SaveLand
		%========== Saving 2-D hydration energy landscape
		fh=fopen('Resistance_landscape.txt','w');
		
		%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
		fprintf(fh,'%s\t','Position');
		for m=1:(length(s)-1)
			fprintf(fh,'%s\t', ProfNames{m});
		end
		fprintf(fh,'%s\n', s{end});
		
		for i=1:length(RBinsZ)
			fprintf(fh,'%16.14g\t', RBinsZ(i));
			for m=1:(length(s)-1)
				fprintf(fh,'%16.14g\t', ResProf(m,i));
			end
			fprintf(fh,'%16.14g\n', ResProf(end,i));
		end
		fclose(fh);
	end
	
	
end


