function [MBinsZ,HydEn]=hydpran(s,PlotProf,PlotLand,PrintProf,PrintLand,ImageProf,ImageLand,SaveProf,SaveLand,AverNeighb,AverMode,AverOutside)
%hydpran is the program for reading and analysis of hydrophobicity profiles/landscape created
%by hydroprof program
if ~isempty(s)
	HydEn=[];
	MBinsZ=[];
	ProfNames={};
	for m=1:length(s)
		
		%=================Read hydration energy profile file into array
		fh=fopen(s{m},'r');
		ProgressBarFile(m);
		%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
		%t=sscanf(fgets(fh),'%s\t');
		ft=fopen('temptemp.txt','w');	%temporal file
		fprintf(ft,'%c',fgets(fh));	%saves the first line with field names from HE profile file
		fclose(ft);
		tProfNames = textread('temptemp.txt','%s','delimiter','\t');
		if length(ProfNames)==0
			ProfNames={tProfNames{2:end}};
		else
			ProfNames=[ProfNames,{tProfNames{2:end}}];
		end
		delete 'temptemp.txt';
		fclose(fh);
		
		tHydEn=textread(s{m},'%f','delimiter','\n','headerlines',1);
		tHydEn=reshape(tHydEn(1:floor(length(tHydEn)/length(tProfNames))*length(tProfNames)),...
			length(tProfNames),floor(length(tHydEn)/length(tProfNames)))';
		MBinsZ=tHydEn(:,1);	%column with position values
		HydEn=[HydEn,tHydEn(:,2:end)];	%columns with hydrophobicity profiles
		disp([num2str(m),'. ',s{m},':      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(tHydEn,2)-1) ,'-profile(s) file read']);
		SndNp(2);
	end
	HydEn=HydEn';
	
	disp(['Total:      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(HydEn,1)) ,'-profile(s) matrix created']);
	
	%========== Plotting 2-D hydration energy landscape
	if PlotProf|PrintProf|ImageProf
		%==========plotting hydration energy profile
		switch AverOutside	%Range of averaging
		case {1,2}	%'Do not average boarding bins',%Averaging boarding bins with outside as 0
			for tt=1:size(HydEn,1)
				figure
				plot(MBinsZ,HydEn(tt,:));
				if PrintProf==1	%Print profile
					print;
				end
				if ImageProf==1	%Print profile
					tstr=['print -dpng ''Initial_property_profile_of_the_',s{tt},'.png'''];
					eval(tstr);
				end
				if PlotProf==0	%Don't plot profile
					close;
				end
			end
			figure
			plot(MBinsZ,HydEn');
		case 3	%'Circular averaging'
			figure	
			plot(MBinsZ,HydEn');	%linear plot
			for tt=1:size(HydEn,1)
				zero_rad=(max(max(HydEn(tt,:)))-min(min(HydEn(tt,:))))/4-min(min(HydEn(tt,:)));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				figure; 
				polar(MBinsZ,[HydEn(tt,:)+zero_rad]','-b');	%Polar plot of hydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-r');
				hold off
				
				zero_rad=(max(max(-HydEn(tt,:)))-min(min(-HydEn(tt,:))))/4-min(min(-HydEn(tt,:)));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				figure; 
				polar(MBinsZ,[-HydEn(tt,:)+zero_rad]','-r');	%Polar plot of hydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-b');
				hold off
			end
        end
        
        if PrintProf==1	%Print profile
            print;
        end
        if ImageProf==1	%Print profile
            tstr=['print -dpng ''Initial_property_profile_of_the_',s{m},'.png'''];
            eval(tstr);
        end
        if PlotProf==0	%Don't plot profile
            close;
        end
    end
    
	if (PlotLand|PrintLand|ImageLand)&(size(HydEn,1) > 2)
		figure
		hp=surfl(MBinsZ,[1:size(HydEn,1)],HydEn);
		colormap('bone');
		shading interp
		set(hp,'EdgeColor','k')
		%light('Position',[ -50 -250 3000 ])
		set(hp,'MeshStyle','row');
		xlabel('Position, A');
		ylabel('PDB srtucture #');
		zlabel('Hydration energy');
		set(gca,'YTick',1:size(HydEn,1));
		set(gca,'YTickLabel',ProfNames);
		if PrintLand==1	%Print landscape
			print;
		end
		if ImageLand==1	%Print landscape
			tstr=['print -dpng ''Initial_property_landscape_-_all_the_files_',s{1},'.png'''];
			eval(tstr);
		end
		if PlotLand==0	%Don't plot landscape
			close;
		end

	end
	
	[HydEn,MBinsZ,Outside]=averhstl(HydEn,MBinsZ,AverNeighb,AverMode,AverOutside);
	%========== Plotting 2-D hydration energy landscape
	
	if PlotProf|PrintProf|ImageProf
		%==========plotting hydration energy profile
		switch AverOutside	%Range of averaging
		case {1,2}	%'Do not average boarding bins',%Averaging boarding bins with outside as 0
			for tt=1:size(HydEn,1)
				figure
				plot(MBinsZ,HydEn(tt,:));
				if PrintProf==1	%Print profile
					print;
				end
				if ImageProf==1	%Print profile
					tstr=['print -dpng ''Corrected_property_profile_of_the_',s{tt},'.png'''];
					eval(tstr);
				end
				if PlotProf==0	%Don't plot profile
					close;
				end
			end
			figure
			plot(MBinsZ,HydEn');
		case 3	%'Circular averaging'
			figure	
			plot(MBinsZ,HydEn');	%linear plot
			for tt=1:size(HydEn,1)
				zero_rad=(max(max(HydEn(tt,:)))-min(min(HydEn(tt,:))))/4-min(min(HydEn(tt,:)));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				figure; 
				polar(MBinsZ,[HydEn(tt,:)+zero_rad]','-b');	%Polar plot of hydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-r');
				hold off
				
				zero_rad=(max(max(-HydEn(tt,:)))-min(min(-HydEn(tt,:))))/4-min(min(-HydEn(tt,:)));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				figure; 
				polar(MBinsZ,[-HydEn(tt,:)+zero_rad]','-r');	%Polar plot of hydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-b');
				hold off
			end
		end
	end
	
	if PrintProf==1	%Print profile
		print;
	end
	if ImageProf==1	%Print profile
		tstr=['print -dpng ''Corrected_property_profile_-_all_the_files_',s{1},'.png'''];
		eval(tstr);
	end
	if PlotProf==0	%Don't plot profile
		close;
	end
	
	if SaveProf
		for m=1:length(s)
			%==========saving separate hydration energy profile
			fh=fopen([s{m},'_aver.txt'],'w');
			fprintf(fh,'%s\t','Position');
			fprintf(fh,'%s\n', s{m});
			for i=1:length(MBinsZ)
				fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
			end
			fclose(fh);
		end
	end
	
	if (PlotLand|PrintLand|ImageLand)&(size(HydEn,1) > 2)
		figure
		hp=surfl(MBinsZ,[1:size(HydEn,1)],HydEn);
		colormap('bone');
		shading interp
		set(hp,'EdgeColor','k')
		%light('Position',[ -50 -250 3000 ])
		set(hp,'MeshStyle','row');
		xlabel('Position, A');
		ylabel('PDB srtucture #');
		zlabel('Hydration energy');
		set(gca,'YTick',1:size(HydEn,1));
		set(gca,'YTickLabel',ProfNames);
        if PrintLand==1	%Print landscape
            print;
        end
        if ImageLand==1	%Print landscape
            tstr=['print -dpng ''Corrected_property_landscape_of_the_',s{1},'.png'''];
            eval(tstr);
        end
        if PlotLand==0	%Don't plot landscape
            close;
        end
	end
	
	if SaveLand
		%========== Saving 2-D hydration energy landscape
		fh=fopen(['Hydration_Energy_Landscape_',s{1},'.txt'],'w');
		
		%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
		fprintf(fh,'%s\t','Position');
		for m=1:(length(s)-1)
			fprintf(fh,'%s\t', s{m});
		end
		fprintf(fh,'%s\n', s{end});
		
		for i=1:length(MBinsZ)
			fprintf(fh,'%16.14g\t', MBinsZ(i));
			for m=1:(length(s)-1)
				fprintf(fh,'%16.14g\t', HydEn(m,i));
			end
			fprintf(fh,'%16.14g\n', HydEn(end,i));
		end
		fclose(fh);
	end
	
	
end


