function [MBinsZ,HydEn]=hydprcomb(s,PlotProf,PlotLand,SaveProf,SaveLand,CombMode,CombFileType,...
		CombFile)
%hydprcomb is the program for combining together property profiles/landscape created
%by hydroprof program
dbstop if error

if ~isempty(s)
	HydEn=[];
	MBinsZ=[];
	ProfNames={};
	for m=1:length(s)
		
		%=================Read hydration energy profile file into array
		fh=fopen(s{m},'r');
		ProgressBarFile(m);
		%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
		%t=sscanf(fgets(fh),'%s\t');
		ft=fopen('temptemp.txt','w');	%temporal file
		fprintf(ft,'%c',fgets(fh));	%saves the first line with field names from HE profile file
		fclose(ft);
		tProfNames = textread('temptemp.txt','%s','delimiter','\t');
		if length(ProfNames)==0
			ProfNames={tProfNames{2:end}};
		else
			ProfNames=[ProfNames,{tProfNames{2:end}}];
		end
		delete 'temptemp.txt';
		fclose(fh);
		
		tHydEn=textread(s{m},'%f','delimiter','\n','headerlines',1);
		tHydEn=reshape(tHydEn(1:floor(length(tHydEn)/length(tProfNames))*length(tProfNames)),...
			length(tProfNames),floor(length(tHydEn)/length(tProfNames)))';
		MBinsZ=tHydEn(:,1);	%column with position values
		HydEn=[HydEn,tHydEn(:,2:end)];	%columns with hydrophobicity profiles
		disp([num2str(m),'. ',s{m},':      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(tHydEn,2)-1) ,'-profile(s) file read']);
		SndNp(2);
	end
	HydEn=HydEn';
	disp(['Total:      ',num2str(length(MBinsZ)), '-bins and ', num2str(size(HydEn,1)) ,'-profile(s) matrix created']);
	
	%=================Read combining profile file into array
	switch CombMode
	case {1 2 3 4 5 6 8 9}
		CombProf=[];
		tCombProf=[];
		tCombProf=textread(CombFile,'%f','delimiter','\n','headerlines',1);
		tCombProf=reshape(tCombProf,2,floor(length(tCombProf)/2))';
		CombMBinsZ=tCombProf(:,1);	%column with position values
		disp(['Profile for combining: ',CombFile,':      ',num2str(length(CombMBinsZ)),...
				'-bins file read']);
		SndNp(2);
		CombProf=tCombProf(:,2)';
	case {7}	%'Average (Ini)'
	end
		
	%========== Plotting 2-D hydration energy landscape
	if PlotProf
	    %==========plotting hydration energy profile
	    figure
	    plot(MBinsZ,HydEn);
		figure
	    plot(CombMBinsZ,CombProf);
	end
	if PlotLand&(size(HydEn,1) > 2)	%Plot landscape of initial profile(s)
	    figure
	    hp=surfl(MBinsZ,[1:size(HydEn,1)],HydEn);
	    colormap('bone');
	    shading interp
	    set(hp,'EdgeColor','k')
	    %light('Position',[ -50 -250 3000 ])
	    set(hp,'MeshStyle','row');
	    xlabel('Position, A');
	    ylabel('PDB srtucture #');
	    zlabel('Hydration energy');
	    set(gca,'YTick',1:size(HydEn,1));
	    set(gca,'YTickLabel',ProfNames);
	end

	%=========== Combining profiles
	
	%--- interpolating combination profile to initial profile bins
	switch CombMode
	case {1 2 3 4 5 6}
		CombProfInt=interp1AGB(CombMBinsZ,CombProf,MBinsZ)';
	case {7 8 9}	%'Average (Ini)'
	end
	
	switch CombMode
	case 1	%'Sum',
		for i=1:size(HydEn,1)
			HydEn(i,:)=HydEn(i,:)+CombProfInt;
		end
	case 2	%'Substract (Ini-Comb)',
		for i=1:size(HydEn,1)
			HydEn(i,:)=HydEn(i,:)-CombProfInt;
		end
	case 3	%'Substract (Comb-Ini)',
		for i=1:size(HydEn,1)
			HydEn(i,:)=CombProfInt-HydEn(i,:);
		end
	case 4	%'Multiply',
		for i=1:size(HydEn,1)
			HydEn(i,:)=HydEn(i,:).*CombProfInt;
		end
	case 5	%'Divide (Ini/Comb)', 
		for i=1:size(HydEn,1)
			HydEn(i,:)=HydEn(i,:)./CombProfInt;
		end
	case 6	%'Divide (Comb/Ini)'
		for i=1:size(HydEn,1)
			HydEn(i,:)=CombProfInt./HydEn(i,:);
		end
	case 7	%'Average (Ini)'
		HydEnR(1,:)=zeros(1,length(MBinsZ));	%Initialize new empty averaged profiles matrix
		HydEnR(1,:)=mean(HydEn,1);	%calculate average profile
		HydEnR(2,:)=std(HydEn,1);	%calculate standard deviation between profiles
		HydEnR(3,:)=HydEnR(2,:)/(length(MBinsZ)-1)^0.5;	%calculate standard error of average profile calculation
		HydEnR(4,:)=HydEnR(1,:)-HydEnR(2,:);	%average profile minus standard deviation
		HydEnR(5,:)=HydEnR(1,:)+HydEnR(2,:);	%average profile plus standard deviation
		HydEnR(6,:)=HydEnR(1,:)-HydEnR(3,:);	%average profile minus standard error
		HydEnR(7,:)=HydEnR(1,:)+HydEnR(3,:);	%average profile plus standard error
		HydEn=HydEnR; %Assign new matrix with calculated statistics instead of old one
	case 8	%'Rebin (Ini by Comb)'
		HydEnR(1,:)=zeros(1,length(CombMBinsZ));	%Initialize new empty rebinned profiles matrix
		for i=1:size(HydEn,1)
			HydEnR(i,:)=interp1AGB(MBinsZ,HydEn(i,:),CombMBinsZ)';	%rebin next profile
		end
		HydEn=HydEnR; %Assign new rebinned matrix instead of old one
		MBinsZ=CombMBinsZ;	%Assign bins from combination profile
	case 9	%'Rebin spline (Ini by Comb)'
		HydEnR(1,:)=zeros(1,length(CombMBinsZ));	%Initialize new empty rebinned profiles matrix
		for i=1:size(HydEn,1)
			%HydEnR(i,:)=interp1AGB(MBinsZ,HydEn(i,:),CombMBinsZ,'spline')';	%rebin next profile
% 			HydEnR(i,:)=interp1AGB(MBinsZ,HydEn(i,:),CombMBinsZ,'cubic')';	%rebin next profile
			HydEnR(i,:)=interp1_new(MBinsZ,HydEn(i,:),CombMBinsZ,'cubic')';	%rebin next profile
		end
		HydEn=HydEnR; %Assign new rebinned matrix instead of old one
		MBinsZ=CombMBinsZ;	%Assign bins from combination profile
	end
	
	
	
	%========== Plotting 2-D hydration energy landscape
	if PlotProf
		switch CombMode
		case {1 2 3 4 5 6 8 9}
			%==========plotting hydration energy profile
			figure
			plot(MBinsZ,HydEn);
		case 7	%'Average (Ini)'
			%==========plotting averaged hydration energy profile
			figure
			plot(MBinsZ,HydEn(1,:));
		end
	end
	
	if SaveProf
		switch CombMode
		case {1 2 3 4 5 6 8 9}
			for m=1:length(s)
				%==========saving separate hydration energy profile
				fh=fopen([s{m},'_comb.txt'],'w');
				fprintf(fh,'%s\t','Position');
				fprintf(fh,'%s\n', s{m});
				for i=1:length(MBinsZ)
					fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
				end
				fclose(fh);
			end
		case 7	%'Average (Ini)'
				%==========saving averaged hydration energy profile
				fh=fopen([s{1},'_aver',num2str(length(s)),'.txt'],'w');
				fprintf(fh,'%s\t','Position');
				fprintf(fh,'%s\n', [s{1},'_aver',num2str(length(s))]);
				for i=1:length(MBinsZ)
					fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(1,i));
				end
				fclose(fh);
		end
	end
	
	if PlotLand&(size(HydEn,1) > 2)
		switch CombMode
		case {1 2 3 4 5 6 8 9}
			figure
			hp=surfl(MBinsZ,[1:size(HydEn,1)],HydEn);
			colormap('bone');
			shading interp
			set(hp,'EdgeColor','k')
			%light('Position',[ -50 -250 3000 ])
			set(hp,'MeshStyle','row');
			xlabel('Position, A');
			ylabel('PDB srtucture #');
			zlabel('Hydration energy');
			set(gca,'YTick',1:size(HydEn,1));
			set(gca,'YTickLabel',ProfNames);
		case 7	%'Average (Ini)'
			figure
			plot(MBinsZ,HydEn(1,:),'k-');
			hold on
			plot(MBinsZ,HydEn(2,:),'k--');
			plot(MBinsZ,HydEn(3,:),'k:');
			plot(MBinsZ,HydEn(4,:),'b--');
			plot(MBinsZ,HydEn(5,:),'b--');
			plot(MBinsZ,HydEn(6,:),'r:');
			plot(MBinsZ,HydEn(7,:),'r:');
			hold off
		end
	end
	
	if SaveLand
		switch CombMode
		case {1 2 3 4 5 6 8 9}
			%========== Saving 2-D hydration energy landscape
			fh=fopen('Hydration_Energy_Landscape.txt','w');
			
			%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
			fprintf(fh,'%s\t','Position');
			for m=1:(length(s)-1)
				fprintf(fh,'%s\t', s{m});
			end
			fprintf(fh,'%s\n', s{end});
			
			for i=1:length(MBinsZ)
				fprintf(fh,'%16.14g\t', MBinsZ(i));
				for m=1:(length(s)-1)
					fprintf(fh,'%16.14g\t', HydEn(m,i));
				end
				fprintf(fh,'%16.14g\n', HydEn(end,i));
			end
			fclose(fh);
		case 7	%'Average (Ini)'
			%========== Saving file with statistical parameters
			fh=fopen(['Aver_stat_',s{1},'.txt'],'w');
			
			%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
			fprintf(fh,'%s\t','Position','Mean','Std. Dev','Std. Err.','Mean-StD','Mean+StD','Mean-StE');
			fprintf(fh,'%s\n', 'Mean+StE');
			
			for i=1:length(MBinsZ)
				fprintf(fh,'%16.14g\t', MBinsZ(i));
				for m=1:6
					fprintf(fh,'%16.14g\t', HydEn(m,i));
				end
				fprintf(fh,'%16.14g\n', HydEn(end,i));
			end
			fclose(fh);
		end
	end

	
end


