function [MBinsZ,HydEn]=hydroprof(s,SaveProf,PlotProf,SaveLand,PlotLand,PrintProf,PrintLand,ImageProf,ImageLand,ProfileType,DataColumn,...
	DataInclude,CritColumn,SelectCrit,ProfileGeom,GridStepType,GridStep,RangeType,MinZ,MaxZ)
%hydroprof program for calculating hydriphobicity profile of protein along z coordinate.
%occypancy column should contain surface(1)/pore(-1) flag to each atom
%beta column should contain hydration energy data (in kcal/mol)
%INPUTS:
%s	- cell array with filenames
%SaveProf	- Save calculated hydration energy profiles
%PlotProf	- Plot calculated hydration energy profiles
%SaveLand	- Save calculated hydration energy landscape
%PlotLand	- Plot calculated hydration energy landscape
%ProfileType	- Select type of property to create profile - hydrophobicity <1>*, electrical charge <2>, Residue exposure summation <3>
%DataColumn	- Column with data for calculation
%DataInclude	- Select data to include into the calculation - all the data <1>*, positive <2>, negative <3>
%CritColumn	- Column with criterion for including into the calculation
%SelectCrit	- Select surface for calculation - outside <1>*, inside <2>, all <3>
%ProfileGeom	- 	Select type of geometry to create profile - vertical (along Z axis) <1>*, circular (view from the Z axis, from negative to positive direction) <2>
%GridStepType -  Type of the calculation of volumetric grid steps - by the step length or number of steps
%GridStep - Length of the grid step (in Angstroms) or number of steps in the grid

%Output
%
dbstop if error

if ~isempty(s)
	ATOM=[];
	%============ATOM array initialization
	ATOM.line=[];	%Number of the line in PDB file
	ATOM.index=[];	%        Atom serial number.
	ATOM.name={};	%          Atom name.
	ATOM.altloc={};	%        Alternate location indicator.
	ATOM.resname={};	%       Residue name.
	ATOM.chain={};	%       Chain identifier.
	ATOM.resid=[];	%        Residue sequence number.
	ATOM.icode={};	%         Code for insertion of residues.
	ATOM.x=[];	%             Orthogonal coordinates for X in Angstroms.
	ATOM.y=[];	%             Orthogonal coordinates for Y in Angstroms.
	ATOM.z=[];	%             Orthogonal coordinates for Z in Angstroms.
	ATOM.occupancy=[];	%     Occupancy.
	ATOM.beta=[];	%    Temperature factor.
	ATOM.segname={};	%         Segment identifier, left-justified.
	ATOM.element={};	%       Element symbol, right-justified.
	ATOM.charge={};	%        Charge on the atom.
	ATOM.pdb=[];	%content of the PDB file
	
	%     Fields(1)=0;%        Atom serial number.
	%     Fields(2)=0; %          Atom name.
	%     Fields(3)=0; %        Alternate location indicator.
	%     Fields(4)=0; %       Residue name.
	%     Fields(5)=0; %       Chain identifier.
	%     Fields(6)=0; %        Residue sequence number.
	%     Fields(7)=0; %         Code for insertion of residues.
	%     Fields(8)=0; %             Orthogonal coordinates for X in Angstroms.
	%     Fields(9)=0; %             Orthogonal coordinates for Y in Angstroms.
	%     Fields(10)=1; %             Orthogonal coordinates for Z in Angstroms.
	%     Fields(11)=1; %     Occupancy.
	%     Fields(12)=1; %    Temperature factor.
	%     Fields(13)=0; %         Segment identifier, left-justified.
	%     Fields(14)=0; %       Element symbol, right-justified.
	%     Fields(15)=0; %        Charge on the atom.
	
	Fields(1:15)=1;
	ProfNames=s;

	for m=1:length(s)
		tic
		ATOM(m)=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
		ProgressBarFile(m);
		disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM(m).line)), '-atoms structure read']);
		
		%=============Writing results to the file
		% 		fidProt=fopen([s{m},'_prot.txt'],'w');
		% 		fidVal=fopen([s{m},'_val.txt'],'w');
		% 		fidPoints=fopen([s{m},'_points.txt'],'w');
		% 		disp(['File: ',s{m}]);
		% 		for Position=1:size(GelImage,1);	%Cycle through the bands lines and forming bands final values
		% 			fprintf(fidVal,'%g\t',BandVal(Position,:));
		% 			fprintf(fidPoints,'%g\t',BandPoints(Position,:));
		% 			fprintf(fidVal,'\n');
		% 			fprintf(fidPoints,'\n');
		% 			if PaperBands==1	%Paper bands are present
		% 				fprintf(fidProt,'%g\t',BandValFin(Position,2:2:BandsNumb));
		% 			else	%No paper bands
		% 				fprintf(fidProt,'%g\t',BandValFin(Position,1:BandsNumb));
		% 			end
		% 			fprintf(fidProt,'\n');
		% 		end
		% 		fclose(fidProt);
		% 		fclose(fidVal);
		% 		fclose(fidPoints);
		toc
		SndNp(2);
	end
	
	switch ProfileGeom
	case 1	%Vertical profile
		for m=1:length(s)
			coord(m).z=ATOM(m).z;
		end
		
		switch RangeType	%The way to calculate min and max values of the range
		case 1	%Auto 1st - values are automatically taken from the PDB coordinates of the structures
			MinZ=min(min([coord(:).z]));
			MaxZ=max(max([coord(:).z]));
		case 2	%User-selected range is used
		end		%The way to calculate min and max values of the range
	case 2	%circular profile
		%=========== calculating angle position for circular profile and putting it into coord array 
		for m=1:length(s)
			coord(m).z=atan2(ATOM(m).y,ATOM(m).x);
		end

		switch RangeType	%The way to calculate min and max values of the range
		case 1	%Auto 1st - values are automatically taken from the PDB coordinates of the structures
			MinZ=-pi;
			MaxZ=pi;
		case 2	%User-selected range is used
		end		%The way to calculate min and max values of the range
	end
	
	
	
	%=========== calculating hydration energy prifiles
	
	%initial settings
% 	if ProfileGeom==2	%circular profile
% 	else %Vertical profile
% 	end
%    BinsZ=MinZ:(MaxZ-MinZ)/BinsNum:MaxZ;	%bins boundaries
    switch GridStepType	%Type of the calculation of slices grid steps - by the step length or number of steps{'Length, A','Steps'}
        % GridStep	- Length of the grid step (in Angstroms) or number of steps in the grid
    case 1	%'Length, A'
        BinsZ=MinZ:GridStep:MaxZ;	%bins boundaries
    case 2	%'Steps'
        BinsZ=MinZ:(MaxZ-MinZ)/GridStep:MaxZ;	%bins boundaries
    end
    MBinsZ=(BinsZ(1:(end-1))+BinsZ(2:end))/2;	%bins medians
    HydEn=zeros(length(s),length(MBinsZ));	%Initializing hydration energy matrix
	FirstExposureCalculation=1;	%Flag for first exposure calculation 
	
	for m=1:length(s)	%Cycle through the files
		switch DataColumn	%Select column in ATOM to read property data
		case 1
			PropData=ATOM(m).index;	%        Atom serial number.
		case 2
			PropData=ATOM(m).name;	%          Atom name.
		case 3
			PropData=ATOM(m).altloc;	%        Alternate location indicator.
		case 4
			PropData=ATOM(m).resname;	%       Residue name.
		case 5
			PropData=ATOM(m).chain;	%       Chain identifier.
		case 6
			PropData=ATOM(m).resid;	%        Residue sequence number.
		case 7
			PropData=ATOM(m).icode;	%         Code for insertion of residues.
		case 8
			PropData=ATOM(m).x;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			PropData=ATOM(m).y;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			PropData=ATOM(m).z;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			PropData=ATOM(m).occupancy;	%     Occupancy.
		case 12
			PropData=ATOM(m).beta;	%    Temperature factor.
		case 13
			PropData=ATOM(m).segname;	%         Segment identifier, left-justified.
		case 14
			PropData=ATOM(m).element;	%       Element symbol, right-justified.
		case 15
			PropData=ATOM(m).charge;	%        Charge on the atom.
		end
		
		switch CritColumn	%Select column in ATOM to read property criterion data
		case 1
			PropCrit=ATOM(m).index;	%        Atom serial number.
		case 2
			PropCrit=ATOM(m).name;	%          Atom name.
		case 3
			PropCrit=ATOM(m).altloc;	%        Alternate location indicator.
		case 4
			PropCrit=ATOM(m).resname;	%       Residue name.
		case 5
			PropCrit=ATOM(m).chain;	%       Chain identifier.
		case 6
			PropCrit=ATOM(m).resid;	%        Residue sequence number.
		case 7
			PropCrit=ATOM(m).icode;	%         Code for insertion of residues.
		case 8
			PropCrit=ATOM(m).x;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			PropCrit=ATOM(m).y;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			PropCrit=ATOM(m).z;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			PropCrit=ATOM(m).occupancy;	%     Occupancy.
		case 12
			PropCrit=ATOM(m).beta;	%    Temperature factor.
		case 13
			PropCrit=ATOM(m).segname;	%         Segment identifier, left-justified.
		case 14
			PropCrit=ATOM(m).element;	%       Element symbol, right-justified.
		case 15
			PropCrit=ATOM(m).charge;	%        Charge on the atom.
			for i=1:length(PropCrit);PropCritN(i)=eval(['0',PropCrit(i)]); end; PropCrit=PropCritN; %evaluation of string to the number
		end
		
		switch ProfileType	%Select type of property to create profile - , hydrophobicity <1>*, electrical charge <2>, Residue exposure summation <3>
		case {1, 2}	%hydrophobicity <1>*, electrical charge <2>
			%	    HydEn(m,:)=distribute([ATOM(m).z;PropData;PropCrit],HydEn(m,:),BinsZ,DataInclude,SelectCrit);	%Filling histogram file
			HydEn(m,:)=distribute([coord(m).z;PropData;PropCrit],HydEn(m,:),BinsZ,DataInclude,SelectCrit);	%Filling histogram file
		case 3	%Residue exposure summation <3>
			if FirstExposureCalculation==1;
				%It is supposed that all the proteins have identical sequence
				NBinsZ=[];
				NBinsZ{1}=ATOM(m).resname{1};	%Initializing array of residue names
				MBinsZ=ATOM(m).resid(1);	%Initializing array of bins medians - it will be residue numbers array now
				HydEn=[];
			end
			
			%==================  Summarizing column per residue
			LastOldNumber=ATOM(m).resid(1);	%The old residue number of first atom
			LastResNumber=1;	%Current number residues array
			HydEn(m,1)=0;		    
			
			for i=1:length(ATOM(m).resid)
				if ATOM(m).resid(i)~= LastOldNumber;	%new residue begins
					if FirstExposureCalculation==1;
						NBinsZ{end+1}=ATOM(m).resname{i};	%Adding new residue name to array. 
						MBinsZ(end+1)=ATOM(m).resid(i);	%Adding new residue number to array.
					end
					LastResNumber=LastResNumber+1;
					HydEn(m,LastResNumber)=0;
				else	%The same residue, adding value
					
				end
				
				%----- Condition check and value addition
				GoCrit=0;
				switch SelectCrit	%Criterion for including the point into consideration
				case 1	%Outer
					if PropCrit(i)==1; GoCrit=1;	end
				case 2	%inner
					if PropCrit(i)==-1; GoCrit=1;	end
				case 3	%all
					GoCrit=1;
				end
				
				GoData=0; 
				switch DataInclude	%Criterion by data value for including the point into consideration
				case 1	%all
					GoData=1;
				case 2	%Outer
					if PropData(i)>0; GoData=1;	end
				case 3	%inner
					if PropData(i)<0; GoData=1;	end
				end
				
				if GoCrit==1&GoData==1  %the point satisfies the criterion and data satisfies data condition
					HydEn(m,LastResNumber)=HydEn(m,LastResNumber)+PropData(i);
				end
				
				%-------- take last poind as an old one
				LastOldNumber=ATOM(m).resid(i);
			end
			FirstExposureCalculation=0;
		end
		%==========plotting hydration energy profile
		
		if PlotProf|PrintProf|ImageProf; 
			figure; 
			if ProfileGeom==2	%circular profile
				plot(MBinsZ,HydEn(m,:));	%linear plot
				
				%convert from polar to cartesian coordinates
				zero_rad=(max(HydEn(m,:))-min(HydEn(m,:)))/4-min(HydEn(m,:));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				%Xplot=(zero_rad+HydEn(m,:)).*cos(MBinsZ);	%
				%Yplot=(zero_rad+HydEn(m,:)).*sin(MBinsZ);	%
				%[Xplot,Yplot] = pol2cart(MBinsZ,HydEn(m,:));
				% 				[Xplot2,Yzero_rad] = pol2cart(MBinsZ,p_zero_rad);
				
				figure; 
				polar(MBinsZ,[HydEn(m,:)+zero_rad],'-b');	%Polar plot of hydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-r');
				hold off
				
				zero_rad=(max(-HydEn(m,:))-min(-HydEn(m,:)))/4-min(-HydEn(m,:));	%radius of zero level circle
				p_zero_rad=ones(size(MBinsZ))*zero_rad;
				figure
				polar(MBinsZ,[-HydEn(m,:)+zero_rad],'-r');	%Polar plot of dehydration energy
				hold on
				polar(MBinsZ,p_zero_rad,'-b');
				hold off
				
				
				% 				figure; 
				% 				plot(Xplot,Yplot);
				% 				hold on
				% 				plot(Xplot2,Yzero_rad);
				% 				hold off
				
			else %Vertical profile
				plot(MBinsZ,HydEn(m,:));
			end
            
            if PrintProf==1	%Print profile
                print;
            end
            if ImageProf==1	%Print profile
                tstr=['print -dpng ''Property_profile_of_the_',s{m},'.png'''];
                eval(tstr);
            end
            if PlotProf==0	%Don't plot profile
                close;
            end
		end
		
		if SaveProf
			
			switch ProfileType	%Select type of property to create profile - , hydrophobicity <1>*, electrical charge <2>, Residue exposure summation <3>
			case {1, 2}	%hydrophobicity <1>*, electrical charge <2>
				%==========saving separate hydration energy profile
				fh=fopen([s{m},'_HE_prof.txt'],'w');
				fprintf(fh,'%s\t','Position');
				fprintf(fh,'%s\n', s{m});
				for i=1:length(MBinsZ)
					fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
				end
				fclose(fh);
			case 3	%Residue exposure summation <3>
				%==========saving separate hydration energy profile
				fh=fopen([s{m},'_HE_prof.txt'],'w');
				fprintf(fh,'%s\t','Position');
				fprintf(fh,'%s\n', s{m});
				for i=1:length(MBinsZ)
					fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
				end
				fclose(fh);
				
				%==========saving separate hydration energy profile with residue names
				fh=fopen([s{m},'_HE_prof-name.txt'],'w');
				fprintf(fh,'%s\t','Residue name');
				fprintf(fh,'%s\t','Residue number');
				fprintf(fh,'%s\n', s{m});
				for i=1:length(MBinsZ)
					fprintf(fh,'%s\t', NBinsZ{i}); fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
				end
				fclose(fh);
				
			end
			
		end
	end
	
	
	m=length(s);
	if m>2&(PlotLand|PrintLand|ImageLand)
		%========== Plotting 2-D hydration energy landscape
		figure
		hp=surfl(MBinsZ,[1:m],HydEn);
		colormap('bone');
		shading interp
		set(hp,'EdgeColor','k')
		%light('Position',[ -50 -250 3000 ])
		set(hp,'MeshStyle','row');
		xlabel('Position, A');
		ylabel('PDB srtucture #');
		zlabel('Hydration energy');
		set(gca,'YTick',1:size(HydEn,1));
		set(gca,'YTickLabel',ProfNames);
                    
        if PrintLand==1	%Print landscape
            print;
        end
        if ImageLand==1	%Print landscape
            tstr=['print -dpng ''Property_landscape_of_the_',s{m},'.png'''];
            eval(tstr);
        end
        if PlotLand==0	%Don't plot landscape
            close;
        end
        
	end
	
	if SaveLand
		
		
		switch ProfileType	%Select type of property to create profile - , hydrophobicity <1>*, electrical charge <2>, Residue exposure summation <3>
		case {1, 2}	%hydrophobicity <1>*, electrical charge <2>
			%========== Saving 2-D hydration energy landscape
			fh=fopen('Property_Landscape.txt','w');
			
			%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
			fprintf(fh,'%s\t','Position');
			for m=1:(length(s)-1)
				fprintf(fh,'%s\t', s{m});
			end
			fprintf(fh,'%s\n', s{end});
			
			for i=1:length(MBinsZ)
				fprintf(fh,'%16.14g\t', MBinsZ(i));
				for m=1:(length(s)-1)
					fprintf(fh,'%16.14g\t', HydEn(m,i));
				end
				fprintf(fh,'%16.14g\n', HydEn(end,i));
			end
			fclose(fh);
		case 3	%Residue exposure summation <3>
			%========== Saving 2-D hydration energy landscape
			fh=fopen('Property_Landscape.txt','w');
			
			%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
			fprintf(fh,'%s\t','Position');
			for m=1:(length(s)-1)
				fprintf(fh,'%s\t', s{m});
			end
			fprintf(fh,'%s\n', s{end});
			
			for i=1:length(MBinsZ)
				fprintf(fh,'%16.14g\t', MBinsZ(i));
				for m=1:(length(s)-1)
					fprintf(fh,'%16.14g\t', HydEn(m,i));
				end
				fprintf(fh,'%16.14g\n', HydEn(end,i));
			end
			fclose(fh);
			
			%========== Saving 2-D hydration energy landscape
			fh=fopen('Property_Landscape-name.txt','w');
			
			%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
			fprintf(fh,'%s\t','Residue name');
			fprintf(fh,'%s\t','Residue number');
			for m=1:(length(s)-1)
				fprintf(fh,'%s\t', s{m});
			end
			fprintf(fh,'%s\n', s{end});
			
			for i=1:length(MBinsZ)
				fprintf(fh,'%s\t', NBinsZ{i});
				fprintf(fh,'%16.14g\t', MBinsZ(i));
				for m=1:(length(s)-1)
					fprintf(fh,'%16.14g\t', HydEn(m,i));
				end
				fprintf(fh,'%16.14g\n', HydEn(end,i));
			end
			fclose(fh);
			
		end
		
	end
	%writePDBfull(s{end},ATOM(end),Fields,1)
	
	beep;
	disp('Finished');
end





%_________________________________________

