%hydroprof program for calculating hydriphobicity profile of protein along z coordinate.
%occypancy column should contain surface(1)/pore(-1) flag to each atom
%beta column should contain hydration energy data (in kcal/mol)

%dbstop in sectar at 27
%cd 'C:\Biophysics\ANDREY\MODELING\PDB\Data'
cd 'C:\Andrey\Other-\Matlab\PDB\Data'
s=[];
[s,v]=uigetfiles('*.pdb','Select a structure file:');
if ~isempty(s)
	ATOM=[];
	%============ATOM array initialization
	ATOM.line=[];	%Number of the line in PDB file
	ATOM.index=[];	%        Atom serial number.
	ATOM.name={};	%          Atom name.
	ATOM.altloc={};	%        Alternate location indicator.
	ATOM.resname={};	%       Residue name.
	ATOM.chain={};	%       Chain identifier.
	ATOM.resid=[];	%        Residue sequence number.
	ATOM.icode={};	%         Code for insertion of residues.
	ATOM.x=[];	%             Orthogonal coordinates for X in Angstroms.
	ATOM.y=[];	%             Orthogonal coordinates for Y in Angstroms.
	ATOM.z=[];	%             Orthogonal coordinates for Z in Angstroms.
	ATOM.occupancy=[];	%     Occupancy.
	ATOM.beta=[];	%    Temperature factor.
	ATOM.segname={};	%         Segment identifier, left-justified.
	ATOM.element={};	%       Element symbol, right-justified.
	ATOM.charge={};	%        Charge on the atom.
	ATOM.pdb=[];	%content of the PDB file

	Fields(1)=0;%        Atom serial number.
	Fields(2)=0; %          Atom name.
	Fields(3)=0; %        Alternate location indicator.
	Fields(4)=0; %       Residue name.
	Fields(5)=0; %       Chain identifier.
	Fields(6)=0; %        Residue sequence number.
	Fields(7)=0; %         Code for insertion of residues.
	Fields(8)=0; %             Orthogonal coordinates for X in Angstroms.
	Fields(9)=0; %             Orthogonal coordinates for Y in Angstroms.
	Fields(10)=1; %             Orthogonal coordinates for Z in Angstroms.
	Fields(11)=1; %     Occupancy.
	Fields(12)=1; %    Temperature factor.
	Fields(13)=0; %         Segment identifier, left-justified.
	Fields(14)=0; %       Element symbol, right-justified.
	Fields(15)=0; %        Charge on the atom.
	
	
	for m=1:length(s)
		tic
		ATOM(m)=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
		disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM(m).line)), '-atoms structure read']);
		
		%=============Writing results to the file
		% 		fidProt=fopen([s{m},'_prot.txt'],'w');
		% 		fidVal=fopen([s{m},'_val.txt'],'w');
		% 		fidPoints=fopen([s{m},'_points.txt'],'w');
		% 		disp(['File: ',s{m}]);
		% 		for Position=1:size(GelImage,1);	%Cycle through the bands lines and forming bands final values
		% 			fprintf(fidVal,'%g\t',BandVal(Position,:));
		% 			fprintf(fidPoints,'%g\t',BandPoints(Position,:));
		% 			fprintf(fidVal,'\n');
		% 			fprintf(fidPoints,'\n');
		% 			if PaperBands==1	%Paper bands are present
		% 				fprintf(fidProt,'%g\t',BandValFin(Position,2:2:BandsNumb));
		% 			else	%No paper bands
		% 				fprintf(fidProt,'%g\t',BandValFin(Position,1:BandsNumb));
		% 			end
		% 			fprintf(fidProt,'\n');
		% 		end
		% 		fclose(fidProt);
		% 		fclose(fidVal);
		% 		fclose(fidPoints);
		toc
	end
	
	
	%===========calculating hydration energy prifiles
	
	%initial settings
	MinZ=min([ATOM(:).z]);
	MaxZ=max([ATOM(:).z]);
	bins=100;	%number of bins for profile
	BinsZ=MinZ:(MaxZ-MinZ)/bins:MaxZ;	%bins boundaries
	MBinsZ=(BinsZ(1:(end-1))+BinsZ(2:end))/2;	%bins medians
	HydEn=zeros(length(s),length(MBinsZ));	%Initializing hydration energy matrix
	
	for m=1:length(s)	%Cycle through the files
		HydEn(m,:)=distribute([ATOM(m).z;ATOM(m).beta;ATOM(m).occupancy],HydEn(m,:),BinsZ,1);	%Filling histogram file
		%==========plotting hydration energy profile
		figure
		plot(MBinsZ,HydEn(m,:));
		
		%==========saving separate hydration energy profile
		fh=fopen([s{m},'_HE_prof.txt'],'w');
		fprintf(fh,'%s\t','Position');
		fprintf(fh,'%s\n', s{m});
		for i=1:length(MBinsZ)
			fprintf(fh,'%16.14g\t', MBinsZ(i));fprintf(fh,'%16.14g\n', HydEn(m,i));
		end
		fclose(fh);
	end
	
	
end

m=length(s);
if m>2
	%========== Plotting 2-D hydration energy landscape
	figure
	hp=surfl(MBinsZ,[1:m],HydEn);
	shading interp
	set(hp,'EdgeColor','k')
	%light('Position',[ -50 -250 3000 ])
	set(hp,'MeshStyle','row');
end

%========== Saving 2-D hydration energy landscape
fh=fopen('Hydration_Energy_Landscape.txt','w');

%fprintf(fh,'%16.14g\t', length(s));fprintf(fh,'%16.14g\n',  length(MBinsZ));
fprintf(fh,'%s\t','Position');
for m=1:(length(s)-1)
	fprintf(fh,'%s\t', s{m});
end
fprintf(fh,'%s\n', s{end});

for i=1:length(MBinsZ)
	fprintf(fh,'%16.14g\t', MBinsZ(i));
	for m=1:(length(s)-1)
		fprintf(fh,'%16.14g\t', HydEn(m,i));
	end
	fprintf(fh,'%16.14g\n', HydEn(end,i));
end
fclose(fh);

writePDBfull(s{end},ATOM(end),Fields,1)

beep;
disp('Finished');




%_________________________________________

