function pdbreorient(s,DestFileType,DestDir,ReorientMode,PlotResult,SelctnColn,CritCombMode,CriteriaList);	%Function for molecule reorienting in PDB files

%INPUTS:
%s	- cell array with filenames
%DestFileType	- PDB file format
%DestColn	- Destination column for data
%DestDir	- Destination directory for data
%ReorientMode	- Alpha-spiral <1> or other <?> reorientation mode
%PlotResult	- Option to plot on the screen the result of reorientation
%SelctnColn	- Selection column - current column with selection criterion
%CritCombMode	- Criteria combination mode - AND <1>, OR <2>, sELECTED CRITERION <3>
%CriteriaList	- List of selection criteria for each column - cell array


%Output
%
%dbstop if error
global ATOM X Y Z

if ~isempty(s)
	ATOM0=[];
	%============ATOM array initialization
	ATOM0.line=[];	%Number of the line in PDB file
	ATOM0.index=[];	%        Atom serial number.
	ATOM0.name={};	%          Atom name.
	ATOM0.altloc={};	%        Alternate location indicator.
	ATOM0.resname={};	%       Residue name.
	ATOM0.chain={};	%       Chain identifier.
	ATOM0.resid=[];	%        Residue sequence number.
	ATOM0.icode={};	%         Code for insertion of residues.
	ATOM0.x=[];	%             Orthogonal coordinates for X in Angstroms.
	ATOM0.y=[];	%             Orthogonal coordinates for Y in Angstroms.
	ATOM0.z=[];	%             Orthogonal coordinates for Z in Angstroms.
	ATOM0.occupancy=[];	%     Occupancy.
	ATOM0.beta=[];	%    Temperature factor.
	ATOM0.segname={};	%         Segment identifier, left-justified.
	ATOM0.element={};	%       Element symbol, right-justified.
	ATOM0.charge={};	%        Charge on the atom.
	ATOM0.pdb=[];	%content of the PDB file
	
	Fields=ones(1,15);    
	
	
	for m=1:length(s)
		cd(DestDir)
		ATOM=[];
		ATOM=ATOM0;	%Initializing ATOM array
		ATOM=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
		ProgressBarFile(m);
		disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM.line)), '-atoms structure read']);
		
		%-----Defining selected atoms for reorientation matrix calculation
		%conditions recognition
		Cond=[];
		Cond.index=eval(['[' CriteriaList{1} ']']);	%        Atom serial number.
		Cond.name=str_2cell(CriteriaList{2});	%          Atom name.
		Cond.altloc=str_2cell(CriteriaList{3});	%        Alternate location indicator.
		Cond.resname=str_2cell(CriteriaList{4});	%       Residue name.
		Cond.chain=str_2cell(CriteriaList{5});	%       Chain identifier.
		Cond.resid=eval(['[' CriteriaList{6} ']']);	%        Residue sequence number.
		Cond.icode=str_2cell(CriteriaList{7});	%         Code for insertion of residues.
		Cond.x=eval(['[' CriteriaList{8} ']']);	%             Orthogonal coordinates for X in Angstroms.
		Cond.y=eval(['[' CriteriaList{9} ']']);	%             Orthogonal coordinates for Y in Angstroms.
		Cond.z=eval(['[' CriteriaList{10} ']']);	%             Orthogonal coordinates for Z in Angstroms.
		Cond.occupancy=eval(['[' CriteriaList{11} ']']);	%     Occupancy.
		Cond.beta=eval(['[' CriteriaList{12} ']']);	%    Temperature factor.
		Cond.segname=str_2cell(CriteriaList{13});	%         Segment identifier, left-justified.
		Cond.element=str_2cell(CriteriaList{14});	%       Element symbol, right-justified.
		Cond.charge=str_2cell(CriteriaList{15});	%        Charge on the atom.
		
		%--- Make the atom selections for each of criteria specified
		selection=[]; selection{15}=[];
		selection{1}=find_coinc(ATOM.index, Cond.index);	%        Atom serial number.
		selection{2}=find_coinc(ATOM.name, Cond.name);		%          Atom name.
		selection{3}=find_coinc(ATOM.altloc, Cond.altloc);		%        Alternate location indicator.
		selection{4}=find_coinc(ATOM.resname, Cond.resname);		%       Residue name.
		selection{5}=find_coinc(ATOM.chain, Cond.chain);		%       Chain identifier.
		selection{6}=find_coinc(ATOM.resid, Cond.resid);		%        Residue sequence number.
		selection{7}=find_coinc(ATOM.icode, Cond.icode);		%         Code for insertion of residues.
		selection{8}=find_coinc(ATOM.x, Cond.x,1);		%             Orthogonal coordinates for X in Angstroms.
		selection{9}=find_coinc(ATOM.y, Cond.y,1);		%             Orthogonal coordinates for Y in Angstroms.
		selection{10}=find_coinc(ATOM.z, Cond.z,1);		%             Orthogonal coordinates for Z in Angstroms.
		selection{11}=find_coinc(ATOM.occupancy, Cond.occupancy,1);		%     Occupancy.
		selection{12}=find_coinc(ATOM.beta, Cond.beta,1);		%    Temperature factor.
		selection{13}=find_coinc(ATOM.segname, Cond.segname);		%         Segment identifier, left-justified.
		selection{14}=find_coinc(ATOM.element, Cond.element);		%       Element symbol, right-justified.
		selection{15}=find_coinc(ATOM.charge, Cond.charge);		%        Charge on the atom.
		
		%---- Calculate final selection based on partional selection lists
		switch CritCombMode	%Criteria combination mode
		case 1	%AND
			selected=ones(size(ATOM.index));	%initialize empty selection list
 			for i=1:15
				selected_i=ones(size(ATOM.index));
				if length(selection{i})>0
					selected_i(selection{i})=0;
					selected(find(selected_i))=0;
				end
			end
			selected=find(selected);
		case 2	%OR
			selected=zeros(size(ATOM.index));	%initialize empty selection list
			for i=1:15
				selected(selection{i})=1;
			end
			selected=find(selected);
		case 3	%sELECTED CRITERION
			selected=selection{SelctnColn};	%final list of selected atoms
		end
		disp('list of selected atoms:');
		selected
		
		%Read initial atom coordinates of selection
		X=ATOM.x(selected);	%             Orthogonal coordinates for X in Angstroms.
		Y=ATOM.y(selected);	%             Orthogonal coordinates for Y in Angstroms.
		Z=ATOM.z(selected);	%             Orthogonal coordinates for Z in Angstroms.
		
		%Make an initial guess about the orientation axis
		deltasXYZ=[(max(X)-min(X)), (max(Y)-min(Y)), (max(Z)-min(Z))];	%Maximal distances for each coordinate
		t=mean([X;Y;Z]');	%Geometry center coordinates for selected atoms group
		X_m=t(1);
		Y_m=t(2);
		Z_m=t(3);
		switch (find(deltasXYZ==max(deltasXYZ)))
		case 1	%Maximal distance is along X axis
		    selected_l=find(X<X_m);	%atoms wit X coordinate smaller than mean X
		    selected_h=find(X>=X_m);	%atoms wit X coordinate smaller than mean X
		case 2	%Maximal distance is along Y axis
		    selected_l=find(Y<Y_m);	%atoms wit X coordinate smaller than mean X
		    selected_h=find(Y>=Y_m);	%atoms wit X coordinate smaller than mean X
		case 3	%Maximal distance is along Z axis
		    selected_l=find(Z<Z_m);	%atoms wit X coordinate smaller than mean X
		    selected_h=find(Z>=Z_m);	%atoms wit X coordinate smaller than mean X
		end
		
	
		X_l=mean(X(selected_l));	%X coordinate of lower mass center
		Y_l=mean(Y(selected_l));	%Y coordinate of lower mass center
		Z_l=mean(Z(selected_l));	%Z coordinate of lower mass center
		X_h=mean(X(selected_h));	%X coordinate of higher mass center
		Y_h=mean(Y(selected_h));	%Y coordinate of higher mass center
		Z_h=mean(Z(selected_h));	%Z coordinate of higher mass center
		
		par_val=[X_l,Y_l,Z_l,X_h,Y_h,Z_h];	%positions for two points defining orientation matrix
		%par_val=par_val+[1 20 30 2 2 2]%!!!remove later
		disp(['Initial orientation line coordinates [X_l,Y_l,Z_l,X_h,Y_h,Z_h]: ',...
				num2str([X_l,Y_l,Z_l,X_h,Y_h,Z_h])]);

% 		%=== block for plotting selection and line
% 		plot3(X,Y,Z,'o-')
% 		hold on
% 		%line(X,Y,Z);%,'.r')
% 		plot3([X_l X_h],[Y_l Y_h],[Z_l Z_h],'.r-')
% 		line([par_val(1) par_val(4)],[par_val(2) par_val(5)],[par_val(3) par_val(6)])
% 		line([X_l X_h],[Y_l Y_h],[Z_l Z_h]);%,'r')
% 		%stereo
% 		hold off
		
		%========== calculation of optimal fitting orientation line
		[t,tt]=equal_dist2line_est(par_val,1);	%Initial stanrd deviation of the distances to the line
		disp(['Initial standard deviation of the distances to the line:', num2str(t)]);
		[par_val,Function_counts,Iterations,fval]=random_search(par_val,'equal_dist2line_est');	%Finding optimal positions for two points defining orientation matrix
		disp(['Number of estimations made: ',num2str(Function_counts)]);
		disp(['Number of iterations made: ',num2str(Iterations)]);
		X_l=par_val(1); 
		Y_l=par_val(2);
		Z_l=par_val(3);
		X_h=par_val(4);
		Y_h=par_val(5);
		Z_h=par_val(6);
		disp(['Final orientation line coordinates [X_l,Y_l,Z_l,X_h,Y_h,Z_h]: ',...
				num2str([X_l,Y_l,Z_l,X_h,Y_h,Z_h])]);

		
		
		
		%____________ Find the rotation axis normal to the orientation line ([X_l,Y_l,Z_l],[X_h,Y_h,Z_h])
		%             and Z axis
		a_r=Y_l-Y_h;	%vector length in X direction
		b_r=X_h-X_l;	%vector length in Y direction
		c_r=0;	%vector length in Z direction
		AcosR=-acos((Z_h-Z_l)/((X_h-X_l)^2+(Y_h-Y_l)^2+(Z_h-Z_l)^2)^0.5);	%Rotation angle - angle of orientation line with Z axis
		disp(['Molecule was rotated by ', num2str(fix(abs(AcosR/3.1415*180))),' degrees']);
		
		%===================== Reorientation of the protein
		%____________ Find the rotation point on the axis found - the nearest point to the geometry center of selected atoms
		[X_n,Y_n,Z_n]=nearest_point([X_l,Y_l,Z_l],[X_h,Y_h,Z_h],[X_m,Y_m,Z_m]);
		
		%=== block for plotting Z-plane projections of the selection and line with smooth interpolations
		if PlotResult
			x = 1:length(X); y = [X; Y; Z];
			pp = spline(x,y);
			yy = ppval(pp, linspace(1,length(X),length(X)*10));
			
			% 		figure
			% 		%=== block for plotting selection and line
			% 		plot3(yy(1,:),yy(2,:),yy(3,:),'-b',X,Y,Z,'ob')
			% 		hold on
			% 		plot3([X_l X_h],[Y_l Y_h],[Z_l Z_h],'xr-')
			% 		plot3(ATOM.x,ATOM.y,ATOM.z,'.g')
			% 		%stereo
			% 		hold off
			figure
			plot(yy(1,:),yy(2,:),'-b',X,Y,'ob',[X_l X_h],[Y_l Y_h],'xr-',[X_n X_n+a_r],[Y_n Y_n+b_r],'.c-')
			axis equal; axis vis3d;
			
			% 		figure
			% 		plot3(yy(1,:),yy(2,:),yy(3,:),'-b',X,Y,Z,'ob',[X_l X_h],[Y_l Y_h],[Z_l Z_h],'xr-',[X_n X_n+a_r],[Y_n Y_n+b_r],[Z_n Z_n+c_r],'.c-')
		end
		
		crd(1:length(ATOM.x),1)=ATOM.x';
		crd(:,2)=ATOM.y';
		crd(:,3)=ATOM.z';
		crd=rotate_coordinates(crd,[X_n,Y_n,Z_n],[a_r,b_r,c_r],AcosR);
		%read transformed coordinates and move rotation center to the (0,0) point
		ATOM.x=crd(:,1)'-X_n;
		ATOM.y=crd(:,2)'-Y_n;
		ATOM.z=crd(:,3)';
		
		%Read atom coordinates of selection
		X=ATOM.x(selected);	%             Orthogonal coordinates for X in Angstroms.
		Y=ATOM.y(selected);	%             Orthogonal coordinates for Y in Angstroms.
		Z=ATOM.z(selected);	%             Orthogonal coordinates for Z in Angstroms.
		
		%=== block for plotting Z-plane projections of the selection and line with smooth interpolations
		if PlotResult
			x = 1:length(X); y = [X; Y; Z];
			pp = spline(x,y);
			yy = ppval(pp, linspace(1,length(X),length(X)*10));
			figure
			plot(yy(1,:),yy(2,:),'-b',X,Y,'ob',X,Y,'.g',0,0,'xr')
			axis equal; axis vis3d;
			% 		figure
			% 		plot3(yy(1,:),yy(2,:),yy(3,:),'-b',X,Y,Z,'ob',[X_l X_h],[Y_l Y_h],[Z_l Z_h],'xr-',[X_n X_n+a_r],[Y_n Y_n+b_r],[Z_n Z_n+c_r],'.c-')
		end
		
		
		writePDBfull([s{m},'_ornt.pdb'],ATOM,Fields,1);
		SndNp(2);
	end
	
	
	%beep;
	disp('Finished');
end



