function 	volmvis(s,CrosNormalType,CrosNormal,CrosType,FromEdit,ToEdit,FromAuto,ToAuto,PlotResult,PrintResult,...
	ImageResult,SaveResult,Symmetry,MakeLinCros,CrosNormalTypeLin,CrosNormalLin,CrosTypeLin,FromEditLin,...
		ToEditLin,FromAutoLin,ToAutoLin,PlotResultLin,PrintResultLin,ImageResultLin,SaveResultLin,SymmetryLin,...
        AutoPlotMinMax,PlotMin,PlotMax,AutoPlotMinMaxLin,PlotMinLin,PlotMaxLin);	%Function to visualize volumetric data array



dbstop if error
%Function to create a set of crossections through volumetric density data, or PDB file, or VRML structure and calculate crossections areas/radii

%	inputs:
%s	- initial files list
%CrosNormalType - 	Type of the normal to the crossection plane
%CrosNormal - 	%X,Y,Z values for the custom Normal to the crossection planes
%CrosType - 	%Type of the crossection cutting
%FromEdi - 	%minimal value for crossection scan range
%ToEdit - 	%maximal value for crossection scan range
%FromAuto - 	%Autodetect minimal value for crossection scan range
%ToAuto - 	%Autodetect maximal value for crossection scan range
%PlotResult=get(findobj(oph,'Tag','o_PlotResult'),'Value');	%Plot the result of the calculation
%ImageResult=get(findobj(oph,'Tag','o_PrintResult'),'Value');	%Print the result of the calculation
%ImageResult=get(findobj(oph,'Tag','o_ImageResult'),'Value');	%Image file of the result of the calculation
%SaveResult=get(findobj(oph,'Tag','o_SaveResult'),'Value');	%Save the result of the calculation
%Symmetry=round(eval(['[',et(findobj(oph,'Tag','o_Symmetry'),'String'),']']));	%Symmetry of the system to be taken into account - slice will be averaged n-fold
%MakeLinCros=	%Make Linear crossection of the preselected slice
%   *Lin - the same parameters for making linear crossection of preselected
%   slice

if ~isempty(s)
	ProgressBarGlobal(0,length(s));%Set current value on the global progress bar
	ProgressBarLocal(0,100);%Set current value on the global progress bar
	for m=1:length(s)	%Cycle through the input files
		tic
        TempZipFileName=unzip_AGA(s{m});  %Temporary Unzip file, if necesary
		load('-MAT',s{m}); %load the file containing volumetric density data in fields VolmData vMBinsX vMBinsY vMBinsZ. These variables will be created in the workspace
        unzip_AGA(s{m},TempZipFileName);  %Remove Temporary Unzip file, if necesary
		%parameters to Convert surface coordinates from volumetric data to their real values
		ProgressBarGlobal((m-1+0.4),length(s));%Set current value on the global progress bar
		ProgressBarFile(m);
        PictureTitle=s{m}; %Title for the pictures
		
		%Block for protein reorientation to make all the crossections normal to Z axis
		switch CrosNormalType	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
			case 1	%'X axis'
				VolmData=permute(VolmData,[3 2 1]);	VolmData(:,:,:)=VolmData(end:-1:1,:,:);
				[vMBinsX,vMBinsZ]=swap(vMBinsX,vMBinsZ(end:-1:1));
                PictureTitle=[PictureTitle,'_CnX'];
			case 2	%'Y axis'
				VolmData=permute(VolmData,[1 3 2]);	VolmData(:,:,:)=VolmData(:,end:-1:1,:);
				[vMBinsY,vMBinsZ]=swap(vMBinsY,vMBinsZ(end:-1:1));
                PictureTitle=[PictureTitle,'_CnY'];
			case 3	%'Z axis'
                PictureTitle=[PictureTitle,'_CnZ'];
			case 4	%'Custom vector'
				disp('Not implemented yet');
				return
		end	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
		
		%Apply Symmetry conditions
		if Symmetry >1	%There is some symmetry
			VolmDataSym=VolmData;	%Initialise symmetrized volumetric data
			[vMBinsXmesh,vMBinsYmesh] = meshgrid(vMBinsX,vMBinsY);
            PictureTitle=[PictureTitle,'_S',num2str(Symmetry)];
			for refl=2:Symmetry	%Cycle through symmetrical reflections
				%******************** Calculate rotated coordinates matrix
				ShiftAngle=2*pi*(refl-1)/Symmetry;	%Angle of the current reflection
				for x=1:length(vMBinsX)
					for y=1:length(vMBinsY)
						[Angle(x,y),Radius(x,y)]=cart2pol(vMBinsX(x),vMBinsY(y));	%Convert to polar coordinates
					end	%y
				end	%x 
				Angle=Angle+ShiftAngle;	%Rotate to the current angle
				[vMBinsXAngle,vMBinsYAngle]=pol2cart(Angle,Radius);	%Convert back to cartesian coordinates
				%figure
				%hp=pcolor(vMBinsX,vMBinsY,sum(VolmData,3)');	%!!!
				for z=1:length(vMBinsZ)	%Cycle through horizontal slices
					VolmDataRefl=interp2(vMBinsXmesh,vMBinsYmesh,VolmData(:,:,z)',vMBinsXAngle,vMBinsYAngle);
					VolmDataSym(:,:,z)=VolmDataSym(:,:,z)+VolmDataRefl;	%Add interolated data to the symmetrized matrix
				end	%Cycle through horizontal slices

			end	%Cycle through symmetrical reflections
			VolmData=VolmDataSym/Symmetry;	%Take symmetrized volumetric data
			VolmData(isnan(VolmData))=0;
			%hp=pcolor(vMBinsX,vMBinsY,sum(VolmData,3)');	%!!!
		end	%There is some symmetry
		
		
		switch CrosType	%Type of the crossection cutting
			case {1,4}	%'Average or sum between 2 palallel planes'
				%Define the range of scanning
				if FromAuto==1	%Autodetect minimal value for crossection scan range 
					FromEdit=min(vMBinsZ);
				end	%Autodetect minimal value for crossection scan range 
				if ToAuto==1	%Autodetect maximal value for crossection scan range 
					ToEdit=max(vMBinsZ);
				end	%Autodetect maximal value for crossection scan range 
				MinZN=min(find(vMBinsZ>=FromEdit));
				MaxZN=max(find(vMBinsZ<=ToEdit));
				
                PictureTitle=[PictureTitle,'_2Pl'];
				%Calculate a slice
                if CrosType==1  %average
                    Slice=mean(VolmData(:,:,(MinZN:MaxZN)),3);
                    PictureTitle=[PictureTitle,'Avr'];
                else    %sum
                    Slice=sum(VolmData(:,:,(MinZN:MaxZN)),3);
                    PictureTitle=[PictureTitle,'Sum'];
                end
                PictureTitle=[PictureTitle,'_',num2str(length(MinZN:MaxZN)),'b',num2str(FromEdit),'to',num2str(ToEdit)];
				
			case {2,5}	%'Average or sum within a cylinder sector'
                PictureTitle=[PictureTitle,'_Cyl'];
				
				
				[Xmesh,Ymesh] = meshgrid(vMBinsX,vMBinsY);
				
				%Define the range of scanning
				if FromAuto==1	%Autodetect minimal value for crossection scan range 
					FromEdit=-180;
				end	%Autodetect minimal value for crossection scan range 
				if ToAuto==1	%Autodetect maximal value for crossection scan range 
					ToEdit=180;
				end	%Autodetect maximal value for crossection scan range 
				MinA=FromEdit*pi/180;	%Start angle
				MaxA=ToEdit*pi/180;	%Finish angle
				%Calculate cylinder bins
				MinZN=min(vMBinsZ);
				MaxZN=max(vMBinsZ);
				
				RadiusN=floor(min(length(vMBinsX),length(vMBinsY))/2);	%Number of bins fitting into Scan cylinder in radial direction
				vMBinsR=0:(vMBinsX(2)-vMBinsX(1)):(vMBinsX(2)-vMBinsX(1))*RadiusN;	%Scan cylinder radius vector
				RadiusN=length(vMBinsR);
				AngleN=round(2*(MaxA-MinA)*vMBinsR(end)/(vMBinsR(2)-vMBinsR(1)));%Number of sectors in Scan cylinder
				vMBinsA=MinA:(MaxA-MinA)/AngleN:MaxA;
				AngleN=length(vMBinsA);
				vMBinsA(end)=MaxA;
				Slice=[];
				%Calculating average in sectors
				for a=1:length(vMBinsA)	%Cycle through angles
					for r=1:length(vMBinsR)	%Cycle through radii
						[XmechCyl(a,r),YmeshCyl(a,r)]=pol2cart(vMBinsA(a),vMBinsR(r));
					end	%Cycle through radii
					ProgressBarLocal(a,length(vMBinsA));%Set current value on the local progress bar
				end	%Cycle through andles
				ProgressBarGlobal((m-1+0.6),length(s));%Set current value on the global progress bar
				
				for z=1:length(vMBinsZ)	%Cycle through horizontal slices
					%Create matrix of necessary radial mesh
					SliceLineCyl = interp2(Xmesh,Ymesh,VolmData(:,:,z)',XmechCyl,YmeshCyl);	%one sector slice interpolated from original slice 2D mesh
                    if CrosType==2  %average
                        Slice(z,1:length(vMBinsR))=mean(SliceLineCyl,1);	%Averaging for all the bins of the same radius
                        PictureTitle=[PictureTitle,'Avr'];
                    else    %sum
                        Slice(z,1:length(vMBinsR))=sum(SliceLineCyl,1);	%Summing for all the bins of the same radius
                        PictureTitle=[PictureTitle,'Sum'];
                    end
					ProgressBarLocal(z,length(vMBinsZ));%Set current value on the local progress bar
				end	%Cycle through horizontal slices
                PictureTitle=[PictureTitle,'_',num2str(FromEdit),'to',num2str(ToEdit)];
				
				%making a symmetrical copy of radial distributions
				Slice(isnan(Slice))=0;
				Slice(:,1:end)=Slice(:,end:-1:1);	Slice(:,(end+1):(end+end-1))=Slice(:,end:-1:2);
				Slice=Slice';
				vMBinsX=[-vMBinsR(end:-1:2),vMBinsR];
				vMBinsY=vMBinsZ;
			case 3	%Surface representation
				%Define the range of scanning
				if FromAuto==1|	ToAuto==1%Autodetect minimal or maximal value for surface 
					tMin=min(VolmData(:));
					tMax=max(VolmData(:));
					if FromAuto==1	%Autodetect minimal value for surface 
						FromEdit=tMin+0.01*(tMax-tMin);
					end	%Autodetect minimal value for surface
					if ToAuto==1	%Autodetect maximal value for surface
						ToEdit=tMax-0.01*(tMax-tMin);
					end	%Autodetect maximal value for surface
				end	%Autodetect minimal value for surface 
		end	%Type of the crossection cutting
		
        clc=clock; TimeStamp=['_',sprintf('%02.0f',clc(2)),'.',sprintf('%02.0f',clc(3)),'.',sprintf('%04.0f',clc(1)),'_',sprintf('%02.0f',clc(4)),'h',sprintf('%02.0f',clc(5)),'m',sprintf('%05.2f',clc(6)),'s'];

		
		
		%********** Plotting the results
		if PlotResult==1|PrintResult==1|ImageResult==1	%Visualize results
			switch  CrosType	%Type of the crossection cutting
				case {1,2,4,5}	%Flat crossections
					figure	%Make the first figure - landscape
					colormap('jet')
					t=colormap;
					colormap(t((end:-1:1),:));
                    SlicePlot=Slice;
					if AutoPlotMinMax == 0  %selected range of values
                        SlicePlot(find(SlicePlot>PlotMax))=PlotMax;
                        SlicePlot(find(SlicePlot<PlotMin))=PlotMin;
                    end  %selected range of values
					hp=surf(vMBinsX,vMBinsY,SlicePlot');
					set(hp,'FaceColor','interp');
					set(hp,'EdgeAlpha',0.3);
                    colorbar;
                    title(PictureTitle,'Interpreter','none','FontSize',6);
					if PrintResult==1	%Print Result
						print;
					end
					if ImageResult==1	%Print Result
						tstr=['print -dpng ''',s{m},TimeStamp,'_vlm_crs_lnd.png'''];
						eval(tstr);
					end
					if PlotResult==0	%Don't plot Result
						close;
					end
					
					figure	%Make the second figure - slice
					%		colormap('gray')
					colormap(t((end:-1:1),:));
					hp=pcolor(vMBinsX,vMBinsY,SlicePlot');
					axis equal; axis vis3d;
					%		axis square; 
					set(hp,'FaceColor','interp');
					set(hp,'EdgeAlpha',0.3);
                    colorbar;
                    title(PictureTitle,'Interpreter','none','FontSize',6);
					if PrintResult==1	%Print Result
						print;
					end
					
				case 3	%Surface at the probability levels
					figure
					vMinX=min(vMBinsX); vMaxX=max(vMBinsX);
					vMinY=min(vMBinsY); vMaxY=max(vMBinsY);
					vMinZ=min(vMBinsZ); vMaxZ=max(vMBinsZ);
					Ax=(vMaxX-vMinX)/(size(VolmData,1)-1); Bx=vMinX-Ax;
					Ay=(vMaxY-vMinY)/(size(VolmData,2)-1); By=vMinY-Ay;
					Az=(vMaxZ-vMinZ)/(size(VolmData,3)-1); Bz=vMinZ-Az;
					FaceColorInner=[0.8 1 1];
					
					if FromEdit < ToEdit	%Transparent surface outside
						Surface=isosurface(permute(VolmData,[2 1 3]),FromEdit); 	%Outer transparent surface
						Surface.vertices(:,1)=Ax*Surface.vertices(:,1)+Bx;
						Surface.vertices(:,2)=Ay*Surface.vertices(:,2)+By;
						Surface.vertices(:,3)=Az*Surface.vertices(:,3)+Bz;
						p = patch(Surface);
						FaceColorOuter='red';
						FaceColorInner='blue';
						set(p,'FaceColor',FaceColorOuter,'EdgeColor','none');
						alpha(.3);
					end
					
					Surface=isosurface(permute(VolmData,[2 1 3]),ToEdit);	%Inner opaque surface
					Surface.vertices(:,1)=Ax*Surface.vertices(:,1)+Bx;
					Surface.vertices(:,2)=Ay*Surface.vertices(:,2)+By;
					Surface.vertices(:,3)=Az*Surface.vertices(:,3)+Bz;
					p = patch(Surface);
					set(p,'FaceColor',FaceColorInner,'EdgeColor','none');
					daspect([1 1 1]); view(3); axis tight; camlight; lighting gouraud
					title(['Surface of the ',s{m},' at the p=',num2str(FromEdit),'&',num2str(ToEdit),' levels']);
					xlabel('X, A'); ylabel('Y, A'); zlabel('Z, A');
					
			end	%Type of the crossection cutting
			if PrintResult==1	%Print Result
				print;
			end
			if ImageResult==1	%Print Result
				tstr=['print -dpng ''',s{m},TimeStamp,'_vlm_crs.png'''];
				eval(tstr);
			end
			if PlotResult==0	%Don't plot Result
				close;
			end
		end	%Visualize results
		
		%******************** Saving the results
		if SaveResult==1	%saves results	
			%========== saves results of symmetrization
			if Symmetry > 1	%There is some symmetry
				tstr=['save ''',s{m},TimeStamp,'_sym.mat'' VolmData vMBinsX vMBinsY vMBinsZ;'];
				eval(tstr);
			end	%There is some symmetry
			
			%Save results of calculation
			switch  CrosType	%Type of the crossection cutting
				case {1,2,4,5}	%Flat crossections
					fh=fopen([s{m},TimeStamp,'_crs.txt'],'w');
					fprintf(fh,'%g\t',0);	%Just empty cell
					fprintf(fh,'%16.14g\t',vMBinsX(1:(end-1)));	fprintf(fh,'%16.14g\n',vMBinsX(end));	%X coordinates
					for y=1:length(vMBinsY)
						fprintf(fh,'%16.14g\t',vMBinsY(y));	fprintf(fh,'%16.14g\t',Slice(1:end-1,y));	fprintf(fh,'%16.14g\n',Slice(end,y));	%X coordinates
					end
					fclose(fh);
				case 3	%Surface at the probability levels
			end	%Type of the crossection cutting
		end	%saves results
		
		
		
		%********************************* Part for making linear **********************************************************
		%crossection of the preselected slice
		if MakeLinCros==1	%Make linear crossection
			
			%Block for protein reorientation to make all the crossections normal to Z axis
			switch CrosNormalTypeLin	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
				case 1	%'X axis'
					Slice=Slice'; Slice(:,:)=Slice(:,end:-1:1);
					[vMBinsX,vMBinsY]=swap(vMBinsX(end:-1:1),vMBinsY);
                    vMBinsX=sort(vMBinsX);
                    vMBinsY=sort(vMBinsY);
                    PictureTitle=[PictureTitle,'_CnX'];
				case 2	%'Y axis'
                    PictureTitle=[PictureTitle,'_CnY'];
				case 3	%'Custom vector'
					disp('Not implemented yet');
					return
			end	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
			
			%Apply Symmetry conditions
			if SymmetryLin >1	%There is some symmetry
				SliceSym=Slice;	%Initialise symmetrized volumetric data
				[vMBinsXmesh,vMBinsYmesh] = meshgrid(vMBinsX,vMBinsY);
                PictureTitle=[PictureTitle,'_S',num2str(SymmetryLin)];
				for refl=2:SymmetryLin	%Cycle through symmetrical reflections
					%******************** Calculate rotated coordinates matrix
					ShiftAngle=2*pi*(refl-1)/SymmetryLin;	%Angle of the current reflection
					for x=1:length(vMBinsX)
						for y=1:length(vMBinsY)
							[Angle(x,y),Radius(x,y)]=cart2pol(vMBinsX(x),vMBinsY(y));	%Convert to polar coordinates
						end	%y
					end	%x 
					Angle=Angle+ShiftAngle;	%Rotate to the current angle
					[vMBinsXAngle,vMBinsYAngle]=pol2cart(Angle,Radius);	%Convert back to cartesian coordinates
					%figure
					%hp=pcolor(vMBinsX,vMBinsY,sum(Slice,3)');	%!!!
						SliceRefl=interp2(vMBinsXmesh,vMBinsYmesh,Slice(:,:)',vMBinsXAngle,vMBinsYAngle);
						SliceSym(:,:)=SliceSym(:,:)+SliceRefl;	%Add interolated data to the symmetrized matrix
				end	%Cycle through symmetrical reflections
				Slice=SliceSym/SymmetryLin;	%Take symmetrized volumetric data
				Slice(isnan(Slice))=0;
				%hp=pcolor(vMBinsX,vMBinsY,sum(Slice,3)');	%!!!
			end	%There is some symmetry
			
			
			switch CrosTypeLin	%Type of the crossection cutting
				case {1,4}	%'Average or sum between 2 palallel planes'
                    PictureTitle=[PictureTitle,'_2Ln'];
					%Define the range of scanning
					if FromAutoLin==1	%Autodetect minimal value for crossection scan range 
						FromEditLin=min(vMBinsY);
					end	%Autodetect minimal value for crossection scan range 
					if ToAutoLin==1	%Autodetect maximal value for crossection scan range 
						ToEditLin=max(vMBinsY);
					end	%Autodetect maximal value for crossection scan range 
					MinYN=min(find(vMBinsY>=FromEditLin));
					MaxYN=max(find(vMBinsY<=ToEditLin));
					
					%Calculate a slice
					if CrosTypeLin==1  %average
						Profile=mean(Slice(:,(MinYN:MaxYN)),2);
                        PictureTitle=[PictureTitle,'Avr'];
					else    %sum
						Profile=sum(Slice(:,(MinYN:MaxYN)),2);
                        PictureTitle=[PictureTitle,'Sum'];
					end
                    PictureTitle=[PictureTitle,'_',num2str(length(MinYN:MaxYN)),'b',num2str(FromEditLin),'to',num2str(ToEditLin)];
					
				case {2,5}	%'Average or sum within a cylinder sector'

                    PictureTitle=[PictureTitle,'_Crc'];
					[Xmesh,Ymesh] = meshgrid(vMBinsX,vMBinsY);
					
					%Define the range of scanning
					if FromAutoLin==1	%Autodetect minimal value for crossection scan range 
						FromEditLin=-180;
					end	%Autodetect minimal value for crossection scan range 
					if ToAutoLin==1	%Autodetect maximal value for crossection scan range 
						ToEditLin=180;
					end	%Autodetect maximal value for crossection scan range 
					MinA=FromEditLin*pi/180;	%Start angle
					MaxA=ToEditLin*pi/180;	%Finish angle
					%Calculate cylinder bins
					
					RadiusN=floor(min(length(vMBinsX),length(vMBinsY))/2);	%Number of bins fitting into Scan cylinder in radial direction
					vMBinsR=0:(vMBinsX(2)-vMBinsX(1)):(vMBinsX(2)-vMBinsX(1))*RadiusN;	%Scan cylinder radius vector
					RadiusN=length(vMBinsR);
					AngleN=round(2*(MaxA-MinA)*vMBinsR(end)/(vMBinsR(2)-vMBinsR(1)));%Number of sectors in Scan cylinder
					vMBinsA=MinA:(MaxA-MinA)/AngleN:MaxA;
					AngleN=length(vMBinsA);
					vMBinsA(end)=MaxA;
					Profile=[];
					%Calculating average in sectors
					for a=1:length(vMBinsA)	%Cycle through angles
						for r=1:length(vMBinsR)	%Cycle through radii
							[XmechCyl(a,r),YmeshCyl(a,r)]=pol2cart(vMBinsA(a),vMBinsR(r));
						end	%Cycle through radii
						ProgressBarLocal(a,length(vMBinsA));%Set current value on the local progress bar
					end	%Cycle through andles
					ProgressBarGlobal((m-1+0.6),length(s));%Set current value on the global progress bar
					
					%Create matrix of necessary radial mesh
					ProfileLineCyl = interp2(Xmesh,Ymesh,Slice(:,:)',XmechCyl,YmeshCyl);	%one sector slice interpolated from original slice 2D mesh
					if CrosType==2  %average
						Profile(1:length(vMBinsR))=mean(ProfileLineCyl,1);	%Averaging for all the bins of the same radius
                        PictureTitle=[PictureTitle,'Avr'];
					else    %sum
						Profile(1:length(vMBinsR))=sum(ProfileLineCyl,1);	%Summing for all the bins of the same radius
                        PictureTitle=[PictureTitle,'Sum'];
					end
					
					%making a symmetrical copy of radial distributions
					Profile(isnan(Profile))=0;
					Profile(1:end)=Profile(end:-1:1);	Profile((end+1):(end+end-1))=Profile(end:-1:2);
					vMBinsX=[-vMBinsR(end:-1:2),vMBinsR];
                    PictureTitle=[PictureTitle,'_',num2str(FromEditLin),'to',num2str(ToEditLin)];
				case 3	%contours representation
				case 6
					return
				case 7
					return
			end	%Type of the crossection cutting
			
			
			
			%********** Plotting the results
			if PlotResultLin==1|PrintResultLin==1|ImageResultLin==1	%Visualize results
				switch  CrosTypeLin	%Type of the crossection cutting
					case {1,2,4,5,6,7}	%Flat crossections
						figure	%Make the first figure
                        ProfilePlot=Profile;
                        if AutoPlotMinMaxLin == 0  %selected range of values
                            ProfilePlot(find(ProfilePlot>PlotMaxLin))=PlotMaxLin;
                            ProfilePlot(find(ProfilePlot<PlotMinLin))=PlotMinLin;
                        end  %selected range of values
						hp=plot(vMBinsX,ProfilePlot);
                        title(PictureTitle,'Interpreter','none','FontSize',6);
						
						
					case 3	%Contour at the probability levels
						figure
% 						vMinX=min(vMBinsX); vMaxX=max(vMBinsX);
% 						vMinY=min(vMBinsY); vMaxY=max(vMBinsY);
% 						Ax=(vMaxX-vMinX)/(size(Slice,1)-1); Bx=vMinX-Ax;
% 						Ay=(vMaxY-vMinY)/(size(Slice,2)-1); By=vMinY-Ay;
						p = contour(vMBinsX,vMBinsY,Slice);
						%title(['Contour of the ',s{m}]);
                        title(PictureTitle,'Interpreter','none','FontSize',6);

						
				end	%Type of the crossection cutting
				if PrintResultLin==1	%Print Result
					print;
				end
				if ImageResultLin==1	%Print Result
					tstr=['print -dpng ''',s{m},TimeStamp,'_vlm_Lin-crs.png'''];
					eval(tstr);
				end
				if PlotResultLin==0	%Don't plot Result
					close;
				end
			end	%Visualize results
			
			%******************** Saving the results
			if SaveResultLin==1	%saves results	
				%========== saves results of symmetrization
				if SymmetryLin > 1	%There is some symmetry
					tstr=['save ''',s{m},TimeStamp,'_Lin-sym.mat'' Slice vMBinsX vMBinsY;'];
					eval(tstr);
				end	%There is some symmetry
				
				%Save results of calculation
				switch  CrosTypeLin	%Type of the crossection cutting
					case {1,2,4,5,6,7}	%Flat crossections
						fh=fopen([s{m},TimeStamp,'_Lin-crs.txt'],'w');
						for x=1:length(vMBinsX)
							fprintf(fh,'%16.14g\t',vMBinsX(x));	fprintf(fh,'%16.14g\n',Profile(x));	%X coordinates and profile
						end
						fclose(fh);
					case 3	%contours at the probability levels
				end	%Type of the crossection cutting
			end	%saves results
		end	%Make linear crossection
		

		SndNp(2);
		POINT=[];	%Clearing POINT array
		ProgressBarGlobal((m),length(s));%Set current value on the global progress bar
	end	%========================Cycle through the input files
	
end	%End of calculation in case there are some files


